(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    137583,       2548]*)
(*NotebookOutlinePosition[    138226,       2570]*)
(*  CellTagsIndexPosition[    138182,       2566]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Paul Nylander", "Text",
  TextAlignment->Right,
  FontFamily->"Times New Roman"],

Cell["\<\
MAE 207, Methods of Computer Modeling in Engineering and the Sciences
Isotropic Rectangular Beam Torsion\
\>", "Text",
  TextAlignment->Center,
  FontFamily->"Times New Roman",
  FontWeight->"Bold"],

Cell[" ", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 3}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 5}],

Cell["beam: http://scienceworld.wolfram.com/physics/Beam.html", "Text"],

Cell[" ", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 0.5}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 3}],

Cell["Finite Element Method (FEM) with Triangular Elements", "Subsubsection"],

Cell[CellGroupData[{

Cell["Roy's notes", "Subsubsection"],

Cell[BoxData[{
    \(Poisson\ \(equation : \ \[Del]\^2 \[Phi]\) = \(\[PartialD]\^2 \[Phi]\/\
\[PartialD]x\^2 + \[PartialD]\^2 \[Phi]\/\[PartialD]y\^2 = \(f \[Rule] \((\
\[Del]u\ v)\)\_\(\[PartialD]\[CapitalOmega]\) - \
\[Integral]\_\[CapitalOmega]\((\[Del]u \[Del]v - 
                      f\ v)\) \[DifferentialD]\[CapitalOmega] = 
          0\)\)\), "\[IndentingNewLine]", 
    \(coordinates\ within\ \(triangle : \ \[Xi]\_1\), \[Xi]\_2\), "\
\[IndentingNewLine]", 
    \(linearized\ \(solution : \ \[Phi] \[TildeTilde] \[Alpha]\_1 + \
\(\[Alpha]\_2\) \[Xi]\_1 + \(\[Alpha]\_3\) \[Xi]\_2\)\), \
"\[IndentingNewLine]", 
    \(node\ 1 : \ \((\[Xi]\_1)\)\_node1 = \(\[Xi]\_11\( = \&?\)0\), \
\((\[Xi]\_2)\)\_node1 = \(\[Xi]\_21\( = \&?\)\(0 \[Rule] 
            q\_1 \[Congruent] \[Phi]\_node1 = \(\[Alpha]\_1 + \(\[Alpha]\_2\) \
\[Xi]\_11 + \(\[Alpha]\_3\) \[Xi]\_21\( = \&?\)\[Alpha]\_1\)\)\)\), "\
\[IndentingNewLine]", 
    \(node\ 2 : \ \((\[Xi]\_1)\)\_node2 = \(\[Xi]\_12\( = \&?\)1\), \
\((\[Xi]\_2)\)\_node2 = \(\[Xi]\_22\( = \&?\)\(0 \[Rule] 
            q\_2 \[Congruent] \[Phi]\_node2 = \(\[Alpha]\_1 + \(\[Alpha]\_2\) \
\[Xi]\_12 + \(\[Alpha]\_3\) \[Xi]\_22\( = \&?\)\[Alpha]\_1 + \
\[Alpha]\_2\)\)\)\), "\[IndentingNewLine]", 
    \(node\ 3 : \ \((\[Xi]\_1)\)\_node3 = \(\[Xi]\_13\( = \&?\)0\), \
\((\[Xi]\_2)\)\_node3 = \(\[Xi]\_23\( = \&?\)\(1 \[Rule] 
            q\_3 \[Congruent] \[Phi]\_node3 = \(\[Alpha]\_1 + \(\[Alpha]\_2\) \
\[Xi]\_13 + \(\[Alpha]\_3\) \[Xi]\_23\( = \&?\)\[Alpha]\_1 + \
\[Alpha]\_3\)\)\)\), "\[IndentingNewLine]", 
    \(u = \(\(q\_1\) N\_1 + \(q\_2\) N\_2 + \(q\_3\) 
            N\_3\( = \&?\)\[Phi]\)\)}], "Text"],

Cell[BoxData[
    RowBox[{\(\[Del]N\_\(\(i\)\(?\)\)\[CenterDot]\[Del]N\_k\), "=", 
      RowBox[{
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(\[PartialD]N\_1\/\[PartialD]x\), \(\[PartialD]N\_2\/\
\[PartialD]x\), \(\[PartialD]N\_3\/\[PartialD]x\)},
              {\(\[PartialD]N\_1\/\[PartialD]y\), \(\[PartialD]N\_2\/\
\[PartialD]y\), \(\[PartialD]N\_3\/\[PartialD]y\)}
              }], "\[NegativeThinSpace]", ")"}], "\[CenterDot]", 
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(\(\[PartialD]\(*\/\[PartialD]\)\)\(*\)\), \(\(\[PartialD]\(*\
\/\[PartialD]\)\)\(*\)\)},
              {\(\(\[PartialD]\(*\/\[PartialD]\)\)\(*\)\), \(\(\[PartialD]\(*\
\/\[PartialD]\)\)\(*\)\)},
              {\(\(\[PartialD]\(*\/\[PartialD]\)\)\(*\)\), \(\(\[PartialD]\(*\
\/\[PartialD]\)\)\(*\)\)}
              }], "\[NegativeThinSpace]", ")"}]}]}]], "Text"],

Cell[BoxData[
    \(what\ is\ \(\(N\)\(?\)\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["class notes: 5/1/06", "Subsubsection"],

Cell[BoxData[
    \(Solve[{0 \[Equal] b\ x1 + c\ x2 + d\ x3, 
        1 \[Equal] b\ x1 + c\ x2 + d\ x3, 
        0 \[Equal] b\ x1 + c\ x2 + d\ x3}, {x1, x2, x3}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Analytical Solution, Nasser's notes", "Subsubsection"],

Cell[BoxData[{"Pandlet", "\[IndentingNewLine]", 
    RowBox[{
      FrameBox[\(\[Del]\^2 \[Phi] = \(-2\) G\ K\),
        BoxMargins->{{0.2, 0.2}, {0.4, 0.4}}], 
      ",", \(angle\ at\ \(twist : \ d\[Alpha]\/dt\)\), 
      ",", \(T\/\(G\ J\)\)}], "\[IndentingNewLine]", \(\[Phi]\^\((\[Alpha], \
\[Eta])\) = \(\(32  
              G\ a\^3\)\/\[Pi]\^3\) \(\[Sum]\+\(n\ odd\)\%\[Infinity]\( 
                1\/n\^3\) \(\((\(-1\))\)\^\(\(n - 1\)\/2\)\) \((1 - 
                Cosh[b]\/Cosh[b])\)\)\)}], "Text"],

Cell[BoxData[
    \(Fig1\)], "Input"],

Cell[BoxData[{\(twist\ \(rate : \ d\[Alpha]\/dz\) = k\ z, \ 
    rectangular\ beam\ \(dimensions : \ a\[Times]b\), \ 
    applied\ \(torque : \ T\)\), "\[IndentingNewLine]", 
    RowBox[{
      " ", \(modulus\ of\ \(rigidity : \ G\) = \(\[Tau]\/\[Gamma] = 
          E\/\(2 \((1 + \[Nu])\)\)\), Young' s\ \(modulus : \ E\), \ 
      Poisson' s\ \(ratio : \ \[Nu]\), shearing\ \(stress : \ \[Tau]\), \ 
      shearing\ \(strain : \ \[Gamma]\)\)}], "\[IndentingNewLine]", \(torsion\
\ \(constant : \ J\) = \(\(16\/3\) \(a\^3\) 
          b \((1 - \(\(196  
                      a\)\/\(b\ \[Pi]\^5\)\) \(\[Sum]\+\(n = 1, 3, 5  \
\[Ellipsis]\)\%\[Infinity]\( 1\/n\^5\) Tanh[\(n\ \[Pi]\ b\)\/\(2  a\)]\))\) = 
        2.1849801331564294`\)\), "\[IndentingNewLine]", \(Prandtl\ stress\ \
\(function : \ \[CapitalPhi]\), 
    Poisson\ \(equation : \ \[Del]\^2 \[CapitalPhi]\) = \(\[PartialD]\^2 \
\[CapitalPhi]\/\[PartialD]x\^2 + \[PartialD]\^2 \
\[CapitalPhi]\/\[PartialD]y\^2 = \(-2\) G\ K\), \[CapitalPhi]\_boundary = 
      0\), "\[IndentingNewLine]", \(Timoshenko : \ \[CapitalPhi] = \(\(32  
              G\ k\ a\)\/\[Pi]\^3\) \(\[Sum]\+\(n = 1, 3, 5  \[Ellipsis]\)\%\
\[Infinity]\( 1\/n\^3\) \(\((\(-1\))\)\^\(\(n - 1\)\/2\)\) \((1 - 
                Cosh[\(n\ \[Pi]\ y\)\/\(2  a\)]\/Cosh[\(n\ \[Pi]\ b\)\/\(2  a\
\)])\) Cos[\(n\ \[Pi]\ x\)\/\(2  a\)]\), 
    linear\ \(twist : \ k\) = 
      T\/\(G\ J\)\), "\[IndentingNewLine]", \(shear\ stress\ tensor\ \(field \
: \ \[Tau]\_yz\) = \(-\(\[PartialD]\[CapitalPhi]\/\[PartialD]x\)\), \
\[Tau]\_xz = \[PartialD]\[CapitalPhi]\/\[PartialD]y, \[Tau]\_yx = 
      0, \[Sigma]\_x = \(\[Sigma]\_y = \(\[Sigma]\_z = 
          0\)\)\), "\[IndentingNewLine]", 
    RowBox[{\(principle\ \(stresses\  : {\[Sigma]\_1, \[Sigma]\_2, \
\[Sigma]\_3}\)\), "=", 
      RowBox[{"Eigenvalues", "[", 
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(\[Sigma]\_xx\), \(\[Tau]\_xy\), \(\[Tau]\_xz\)},
              {\(\[Tau]\_yx\), \(\[Sigma]\_yy\), \(\[Tau]\_yz\)},
              {\(\[Tau]\_zx\), \(\[Tau]\_zy\), \(\[Sigma]\_zz\)}
              }], "\[NegativeThinSpace]", ")"}], 
        "]"}]}], "\[IndentingNewLine]", \(Von\ Mises\ \(stress : \ \
\[Sigma]\_v\) = \(\@\(\((\((\[Sigma]\_1 - \[Sigma]\_2)\)\^2 + \((\[Sigma]\_2 \
- \[Sigma]\_3)\)\^2 + \((\[Sigma]\_3 - \[Sigma]\_1)\)\^2)\)/2\) = \((3 \((\
\[Tau]\_xz\%2 + \[Tau]\_yz\%2)\))\)\^\(1/2\)\)\), "\[IndentingNewLine]", \
\(strain\ tensor\ field\ \((material\ constitutive\ relation)\)\), "\
\[IndentingNewLine]", \(\[Epsilon]\_x = \(\(1\/E\) \((\[Sigma]\_x - \[Nu] \((\
\[Sigma]\_y + \[Sigma]\_z)\))\) = 
        0\), \[Epsilon]\_y = \(\(1\/E\) \((\[Sigma]\_y - \[Nu] \((\[Sigma]\_x \
+ \[Sigma]\_z)\))\) = 
        0\), \[Epsilon]\_z = \(\(1\/E\) \((\[Sigma]\_z - \[Nu] \((\[Sigma]\_x \
+ \[Sigma]\_y)\))\) = 
        0\)\), "\[IndentingNewLine]", \(\[Gamma]\_xy = \(\[Tau]\_xy\/G = 
        0\), \[Gamma]\_yz = \[Tau]\_yz\/G, \[Gamma]\_xz = \[Tau]\_xz\/G\), "\
\[IndentingNewLine]", \(angle\ of\ \(twist : \ \[Alpha]\) = k\ z\)}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(a = \(b = 2\); T = \(G = 1\); J = 2.1849801331564294`; 
    k = T\/\(G\ J\); \[CapitalPhi] = \(\(32  G\ k\ a\)\/\[Pi]\^3\) 
        Sum[\(1\/n\^3\) \(\((\(-1\))\)\^\(\(n - 1\)\/2\)\) \((1 - 
                Cosh[\(n\ \[Pi]\ y\)\/\(2  a\)]\/Cosh[\(n\ \[Pi]\ b\)\/\(2  a\
\)])\) Cos[\(n\ \[Pi]\ x\)\/\(2  a\)], {n, 1, 10, 
            2}]; \[Tau]\_yz = \(-\[PartialD]\_x \[CapitalPhi]\); \[Tau]\_xz = \
\[PartialD]\_y \[CapitalPhi];\), "\[IndentingNewLine]", 
    \(\(DensityPlot[\[Tau]\_xz, {x, \(-a\)/2, a/2}, {y, \(-a\)/2, a/2}, 
        PlotPoints \[Rule] 100, Mesh \[Rule] False, 
        FrameLabel \[Rule] {"\<x\>", "\<y\>"}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.480769 0.5 0.480769 [
[.01923 -0.0125 -6 -9 ]
[.01923 -0.0125 6 0 ]
[.25962 -0.0125 -12 -9 ]
[.25962 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74038 -0.0125 -9 -9 ]
[.74038 -0.0125 9 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5.0625 -22.1875 ]
[.5 -0.0125 5.0625 -9 ]
[-0.0125 .01923 -12 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -24 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -18 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -37.1875 -5.0625 ]
[-0.01875 .5 -24 5.0625 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(-1)] .01923 -0.0125 0 1 Mshowa
.25962 0 m
.25962 .00625 L
s
[(-0.5)] .25962 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.74038 0 m
.74038 .00625 L
s
[(0.5)] .74038 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66.0625 -26.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.125 13.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01923 m
.00625 .01923 L
s
[(-1)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(-0.5)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(0.5)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(1)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .06731 m
.00375 .06731 L
s
0 .11538 m
.00375 .11538 L
s
0 .16346 m
.00375 .16346 L
s
0 .21154 m
.00375 .21154 L
s
0 .30769 m
.00375 .30769 L
s
0 .35577 m
.00375 .35577 L
s
0 .40385 m
.00375 .40385 L
s
0 .45192 m
.00375 .45192 L
s
0 .54808 m
.00375 .54808 L
s
0 .59615 m
.00375 .59615 L
s
0 .64423 m
.00375 .64423 L
s
0 .69231 m
.00375 .69231 L
s
0 .78846 m
.00375 .78846 L
s
0 .83654 m
.00375 .83654 L
s
0 .88462 m
.00375 .88462 L
s
0 .93269 m
.00375 .93269 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -96.6563 -10.5938 Mabsadd m
1 1 Mabs scale
currentpoint translate
66.0625 10.5938 translate
90 rotate
-66.0625 -10.5938 translate
0 21.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.125 13.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01923 .99375 m
.01923 1 L
s
.25962 .99375 m
.25962 1 L
s
.5 .99375 m
.5 1 L
s
.74038 .99375 m
.74038 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.21154 .99625 m
.21154 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.40385 .99625 m
.40385 1 L
s
.45192 .99625 m
.45192 1 L
s
.54808 .99625 m
.54808 1 L
s
.59615 .99625 m
.59615 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.78846 .99625 m
.78846 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .06731 m
1 .06731 L
s
.99625 .11538 m
1 .11538 L
s
.99625 .16346 m
1 .16346 L
s
.99625 .21154 m
1 .21154 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .35577 m
1 .35577 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .45192 m
1 .45192 L
s
.99625 .54808 m
1 .54808 L
s
.99625 .59615 m
1 .59615 L
s
.99625 .64423 m
1 .64423 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .83654 m
1 .83654 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .93269 m
1 .93269 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
100 string
100 100 8 [100 0 0 100 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
DFE1E2E3E4E5E7E8E9EAEBECEDEEEFF0F1F2F3F3F4F5F6F6F7F8F8F9FAFAFBFBFCFCFCFD
FDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFCFCFCFBFBFAFA
F9F8F8F7F6F6F5F4F3F3F2F1F0EFEEEDECEBEAE9E8E7E5E4E3E2E1DF
DDDEDFE1E2E3E4E5E6E7E8EAEAEBECEDEEEFF0F1F1F2F3F4F4F5F5F6F7F7F8F8F9F9F9FA
FAFBFBFBFBFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFCFBFBFBFBFAFAF9F9F9F8F8F7F7
F6F5F5F4F4F3F2F1F1F0EFEEEDECEBEAEAE8E7E6E5E4E3E2E1DFDEDD
DBDCDDDEDFE1E2E3E4E5E6E7E8E9EAEBEBECEDEEEFEFF0F1F1F2F3F3F4F4F5F5F6F6F7F7
F7F8F8F8F8F9F9F9F9F9F9F9F9FAFAF9F9F9F9F9F9F9F9F8F8F8F8F7F7F7F6F6F5F5F4F4
F3F3F2F1F1F0EFEFEEEDECEBEBEAE9E8E7E6E5E4E3E2E1DFDEDDDCDB
D8D9DBDCDDDEDFE0E1E2E3E4E5E6E7E8E9EAEAEBECEDEDEEEFEFF0F0F1F1F2F2F3F3F4F4
F4F5F5F5F5F6F6F6F6F6F6F6F7F7F7F7F6F6F6F6F6F6F6F5F5F5F5F4F4F4F3F3F2F2F1F1
F0F0EFEFEEEDEDECEBEAEAE9E8E7E6E5E4E3E2E1E0DFDEDDDCDBD9D8
D6D7D8D9DBDCDDDEDFE0E1E2E3E4E4E5E6E7E8E8E9EAEBEBECECEDEEEEEFEFF0F0F0F1F1
F1F2F2F2F3F3F3F3F3F3F3F4F4F4F4F4F4F3F3F3F3F3F3F3F2F2F2F1F1F1F0F0F0EFEFEE
EEEDECECEBEBEAE9E8E8E7E6E5E4E4E3E2E1E0DFDEDDDCDBD9D8D7D6
D4D5D6D7D8D9DADBDCDDDEDFE0E1E2E3E4E4E5E6E7E7E8E9E9EAEAEBEBECECEDEDEEEEEE
EFEFEFEFF0F0F0F0F0F1F1F1F1F1F1F1F1F1F1F0F0F0F0F0EFEFEFEFEEEEEEEDEDECECEB
EBEAEAE9E9E8E7E7E6E5E4E4E3E2E1E0DFDEDDDCDBDAD9D8D7D6D5D4
D1D3D4D5D6D7D8D9DADBDCDDDEDFDFE0E1E2E2E3E4E5E5E6E6E7E8E8E9E9EAEAEAEBEBEB
ECECECEDEDEDEDEDEEEEEEEEEEEEEEEEEEEEEEEEEDEDEDEDEDECECECEBEBEBEAEAEAE9E9
E8E8E7E6E6E5E5E4E3E2E2E1E0DFDFDEDDDCDBDAD9D8D7D6D5D4D3D1
CFD0D1D3D4D5D6D7D8D9D9DADBDCDDDEDEDFE0E1E1E2E3E3E4E4E5E5E6E6E7E7E8E8E8E9
E9E9EAEAEAEAEAEBEBEBEBEBEBEBEBEBEBEBEBEBEBEAEAEAEAEAE9E9E9E8E8E8E7E7E6E6
E5E5E4E4E3E3E2E1E1E0DFDEDEDDDCDBDAD9D9D8D7D6D5D4D3D1D0CF
CDCECFD0D1D2D3D4D5D6D7D8D9DADADBDCDDDDDEDFDFE0E0E1E2E2E3E3E4E4E4E5E5E6E6
E6E6E7E7E7E7E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E8E7E7E7E7E6E6E6E6E5E5E4E4E4E3
E3E2E2E1E0E0DFDFDEDDDDDCDBDADAD9D8D7D6D5D4D3D2D1D0CFCECD
CBCCCDCECFD0D1D2D3D4D5D5D6D7D8D9D9DADBDBDCDDDDDEDEDFDFE0E0E1E1E2E2E2E3E3
E3E4E4E4E4E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E5E4E4E4E4E3E3E3E2E2E2E1E1E0
E0DFDFDEDEDDDDDCDBDBDAD9D9D8D7D6D5D5D4D3D2D1D0CFCECDCCCB
C9CACBCCCDCECFD0D0D1D2D3D4D5D5D6D7D8D8D9D9DADBDBDCDCDDDDDEDEDFDFDFE0E0E0
E1E1E1E1E2E2E2E2E2E2E2E2E3E3E3E3E2E2E2E2E2E2E2E2E1E1E1E1E0E0E0DFDFDFDEDE
DDDDDCDCDBDBDAD9D9D8D8D7D6D5D5D4D3D2D1D0D0CFCECDCCCBCAC9
C7C8C9CACBCCCCCDCECFD0D1D1D2D3D4D4D5D6D6D7D8D8D9D9DADADBDBDCDCDCDDDDDDDE
DEDEDEDFDFDFDFDFDFE0E0E0E0E0E0E0E0E0E0DFDFDFDFDFDFDEDEDEDEDDDDDDDCDCDCDB
DBDADAD9D9D8D8D7D6D6D5D4D4D3D2D1D1D0CFCECDCCCCCBCAC9C8C7
C5C6C7C7C8C9CACBCCCDCECECFD0D1D1D2D3D3D4D4D5D6D6D7D7D8D8D8D9D9DADADADBDB
DBDBDCDCDCDCDCDDDDDDDDDDDDDDDDDDDDDDDDDDDDDCDCDCDCDCDBDBDBDBDADADAD9D9D8
D8D8D7D7D6D6D5D4D4D3D3D2D1D1D0CFCECECDCCCBCAC9C8C7C7C6C5
C3C3C4C5C6C7C8C9CACACBCCCDCDCECFCFD0D1D1D2D2D3D4D4D5D5D5D6D6D7D7D7D8D8D8
D9D9D9D9D9DADADADADADADADADADADADADADADADADADAD9D9D9D9D9D8D8D8D7D7D7D6D6
D5D5D5D4D4D3D2D2D1D1D0CFCFCECDCDCCCBCACAC9C8C7C6C5C4C3C3
C0C1C2C3C4C5C6C7C7C8C9CACACBCCCCCDCECECFCFD0D0D1D1D2D2D3D3D4D4D4D5D5D5D6
D6D6D6D7D7D7D7D7D7D7D7D8D8D8D8D8D8D7D7D7D7D7D7D7D7D6D6D6D6D5D5D5D4D4D4D3
D3D2D2D1D1D0D0CFCFCECECDCCCCCBCACAC9C8C7C7C6C5C4C3C2C1C0
BEBFC0C1C2C3C4C4C5C6C7C7C8C9C9CACBCBCCCCCDCDCECECFCFD0D0D1D1D1D2D2D2D3D3
D3D3D4D4D4D4D4D5D5D5D5D5D5D5D5D5D5D5D5D5D5D4D4D4D4D4D3D3D3D3D2D2D2D1D1D1
D0D0CFCFCECECDCDCCCCCBCBCAC9C9C8C7C7C6C5C4C4C3C2C1C0BFBE
BCBDBEBFC0C1C1C2C3C4C4C5C6C6C7C8C8C9C9CACBCBCCCCCCCDCDCECECFCFCFD0D0D0D0
D1D1D1D1D1D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D1D1D1D1D1D0D0D0D0CFCFCFCE
CECDCDCCCCCCCBCBCAC9C9C8C8C7C6C6C5C4C4C3C2C1C1C0BFBEBDBC
BABBBCBDBEBEBFC0C1C1C2C3C3C4C5C5C6C6C7C8C8C9C9CACACACBCBCCCCCCCDCDCDCECE
CECECECFCFCFCFCFCFCFCFD0D0D0D0D0D0CFCFCFCFCFCFCFCFCECECECECECDCDCDCCCCCC
CBCBCACACAC9C9C8C8C7C6C6C5C5C4C3C3C2C1C1C0BFBEBEBDBCBBBA
B8B9BABBBCBCBDBEBFBFC0C1C1C2C2C3C4C4C5C5C6C6C7C7C8C8C8C9C9C9CACACACBCBCB
CBCCCCCCCCCCCCCDCDCDCDCDCDCDCDCDCDCDCDCDCDCCCCCCCCCCCCCBCBCBCBCACACAC9C9
C9C8C8C8C7C7C6C6C5C5C4C4C3C2C2C1C1C0BFBFBEBDBCBCBBBAB9B8
B6B7B8B9BABABBBCBCBDBEBEBFC0C0C1C1C2C2C3C3C4C4C5C5C5C6C6C7C7C7C8C8C8C8C9
C9C9C9C9CACACACACACACACACACACACACACACACACACACACAC9C9C9C9C9C8C8C8C8C7C7C7
C6C6C5C5C5C4C4C3C3C2C2C1C1C0C0BFBEBEBDBCBCBBBABAB9B8B7B6
B5B5B6B7B7B8B9BABABBBBBCBDBDBEBEBFBFC0C0C1C1C2C2C3C3C3C4C4C4C5C5C5C6C6C6
C6C6C7C7C7C7C7C7C7C8C8C8C8C8C8C8C8C8C8C7C7C7C7C7C7C7C6C6C6C6C6C5C5C5C4C4
C4C3C3C3C2C2C1C1C0C0BFBFBEBEBDBDBCBBBBBABAB9B8B7B7B6B5B5
B3B3B4B5B5B6B7B7B8B9B9BABABBBCBCBDBDBEBEBFBFBFC0C0C1C1C1C2C2C2C3C3C3C3C4
C4C4C4C4C4C5C5C5C5C5C5C5C5C5C5C5C5C5C5C5C5C5C5C4C4C4C4C4C4C3C3C3C3C2C2C2
C1C1C1C0C0BFBFBFBEBEBDBDBCBCBBBABAB9B9B8B7B7B6B5B5B4B3B3
B1B1B2B3B3B4B5B5B6B7B7B8B8B9B9BABABBBBBCBCBDBDBDBEBEBEBFBFBFC0C0C0C1C1C1
C1C1C2C2C2C2C2C2C2C2C2C2C3C3C3C3C2C2C2C2C2C2C2C2C2C2C1C1C1C1C1C0C0C0BFBF
BFBEBEBEBDBDBDBCBCBBBBBABAB9B9B8B8B7B7B6B5B5B4B3B3B2B1B1
AFAFB0B1B1B2B3B3B4B4B5B6B6B7B7B8B8B9B9B9BABABBBBBBBCBCBCBDBDBDBEBEBEBEBE
BFBFBFBFBFBFC0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0BFBFBFBFBFBFBEBEBEBEBEBDBDBD
BCBCBCBBBBBBBABAB9B9B9B8B8B7B7B6B6B5B4B4B3B3B2B1B1B0AFAF
ADAEAEAFAFB0B1B1B2B2B3B3B4B4B5B5B6B6B7B7B8B8B8B9B9B9BABABABBBBBBBBBCBCBC
BCBCBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBCBCBCBCBCBBBBBBBBBA
BABAB9B9B9B8B8B8B7B7B6B6B5B5B4B4B3B3B2B2B1B1B0AFAFAEAEAD
ABACACADADAEAFAFB0B0B1B1B2B2B3B3B4B4B4B5B5B6B6B6B7B7B7B8B8B8B8B9B9B9B9BA
BABABABABABABBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBABABABABABABAB9B9B9B9B8B8B8
B8B7B7B7B6B6B6B5B5B4B4B4B3B3B2B2B1B1B0B0AFAFAEADADACACAB
A9AAAAABABACADADAEAEAFAFB0B0B1B1B1B2B2B3B3B3B4B4B4B5B5B5B5B6B6B6B6B7B7B7
B7B7B8B8B8B8B8B8B8B8B8B8B8B8B8B8B8B8B8B8B8B8B8B8B8B8B7B7B7B7B7B6B6B6B6B5
B5B5B5B4B4B4B3B3B3B2B2B1B1B1B0B0AFAFAEAEADADACABABAAAAA9
A7A8A8A9AAAAABABACACADADADAEAEAFAFB0B0B0B1B1B1B2B2B2B3B3B3B3B4B4B4B4B4B5
B5B5B5B5B5B5B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B5B5B5B5B5B5B5B4B4B4B4B4B3B3
B3B3B2B2B2B1B1B1B0B0B0AFAFAEAEADADADACACABABAAAAA9A8A8A7
A5A6A7A7A8A8A9A9AAAAAAABABACACADADADAEAEAEAFAFAFB0B0B0B0B1B1B1B1B2B2B2B2
B2B2B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B3B2B2B2B2B2B2B1B1B1B1
B0B0B0B0AFAFAFAEAEAEADADADACACABABAAAAAAA9A9A8A8A7A7A6A5
A4A4A5A5A6A6A7A7A8A8A8A9A9AAAAAAABABABACACACADADADAEAEAEAEAFAFAFAFAFB0B0
B0B0B0B0B0B0B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B0B0B0B0B0B0B0B0AFAFAFAFAFAE
AEAEAEADADADACACACABABABAAAAAAA9A9A8A8A8A7A7A6A6A5A5A4A4
A2A2A3A3A4A4A5A5A5A6A6A7A7A7A8A8A9A9A9AAAAAAAAABABABACACACACACADADADADAD
ADAEAEAEAEAEAEAEAEAEAEAEAEAEAEAEAEAEAEAEAEAEAEAEAEAEAEADADADADADADACACAC
ACACABABABAAAAAAAAA9A9A9A8A8A7A7A7A6A6A5A5A5A4A4A3A3A2A2
A0A0A1A1A2A2A3A3A3A4A4A5A5A5A6A6A6A7A7A7A8A8A8A8A9A9A9A9AAAAAAAAAAABABAB
ABABABABABACACACACACACACACACACACACACACACACACACABABABABABABABABAAAAAAAAAA
A9A9A9A9A8A8A8A8A7A7A7A6A6A6A5A5A5A4A4A3A3A3A2A2A1A1A0A0
9E9F9F9FA0A0A1A1A1A2A2A3A3A3A4A4A4A5A5A5A5A6A6A6A6A7A7A7A7A8A8A8A8A8A8A8
A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A9A8A8A8A8A8A8A8A7
A7A7A7A6A6A6A6A5A5A5A5A4A4A4A3A3A3A2A2A1A1A1A0A09F9F9F9E
9C9D9D9E9E9E9F9F9FA0A0A1A1A1A2A2A2A2A3A3A3A3A4A4A4A4A5A5A5A5A5A6A6A6A6A6
A6A6A6A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A6A6A6A6A6A6A6A6A5A5A5
A5A5A4A4A4A4A3A3A3A3A2A2A2A2A1A1A1A0A09F9F9F9E9E9E9D9D9C
9B9B9B9C9C9C9D9D9E9E9E9E9F9F9FA0A0A0A0A1A1A1A1A2A2A2A2A2A3A3A3A3A3A3A4A4
A4A4A4A4A4A4A4A4A4A4A5A5A5A5A5A5A5A5A4A4A4A4A4A4A4A4A4A4A4A4A3A3A3A3A3A3
A2A2A2A2A2A1A1A1A1A0A0A0A09F9F9F9E9E9E9E9D9D9C9C9C9B9B9B
99999A9A9A9B9B9B9C9C9C9C9D9D9D9E9E9E9E9F9F9F9F9FA0A0A0A0A0A1A1A1A1A1A1A1
A1A2A2A2A2A2A2A2A2A2A2A2A2A2A2A2A2A2A2A2A2A2A2A2A2A2A2A1A1A1A1A1A1A1A1A0
A0A0A0A09F9F9F9F9F9E9E9E9E9D9D9D9C9C9C9C9B9B9B9A9A9A9999
97979898989999999A9A9A9A9B9B9B9B9C9C9C9C9D9D9D9D9D9E9E9E9E9E9E9E9F9F9F9F
9F9F9F9F9F9FA0A0A0A0A0A0A0A0A0A0A0A0A0A0A0A09F9F9F9F9F9F9F9F9F9F9E9E9E9E
9E9E9E9D9D9D9D9D9C9C9C9C9B9B9B9B9A9A9A9A9999999898989797
959696969697979798989898999999999A9A9A9A9A9B9B9B9B9B9B9C9C9C9C9C9C9C9D9D
9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9D9C9C9C9C9C9C
9C9B9B9B9B9B9B9A9A9A9A9A99999999989898989797979696969695
93949494959595959696969697979797979898989898999999999999999A9A9A9A9A9A9A
9A9A9A9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9B9A9A9A9A9A9A9A9A9A9A99
99999999999998989898989797979797969696969595959594949493
929292939393939394949494959595959596969696969697979797979797979898989898
989898989898989898989898989898989898989898989898989898989898989898979797
97979797979696969696969595959595949494949393939393929292
909090919191919292929292939393939393949494949494949595959595959595959596
969696969696969696969696969696969696969696969696969696969695959595959595
95959594949494949494939393939393929292929291919191909090
8E8E8F8F8F8F8F9090909090919191919191919292929292929292939393939393939393
939393939394949494949494949494949494949494949493939393939393939393939393
9392929292929292929191919191919190909090908F8F8F8F8F8E8E
8C8D8D8D8D8D8E8E8E8E8E8E8F8F8F8F8F8F8F8F90909090909090909090919191919191
919191919191919191919191919191919191919191919191919191919191919191919090
90909090909090908F8F8F8F8F8F8F8F8E8E8E8E8E8E8D8D8D8D8D8C
8B8B8B8B8B8C8C8C8C8C8C8C8D8D8D8D8D8D8D8D8D8E8E8E8E8E8E8E8E8E8E8E8E8E8F8F
8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8F8E8E8E8E8E8E
8E8E8E8E8E8E8E8D8D8D8D8D8D8D8D8D8C8C8C8C8C8C8C8B8B8B8B8B
898989898A8A8A8A8A8A8A8A8B8B8B8B8B8B8B8B8B8B8B8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8C8C8C8D8D8D8D8D8D8D8D8D8D8D8D8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C8C
8C8C8C8C8C8B8B8B8B8B8B8B8B8B8B8B8A8A8A8A8A8A8A8A89898989
87878888888888888888888889898989898989898989898989898A8A8A8A8A8A8A8A8A8A
8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A8A
8A8A8989898989898989898989898989888888888888888888888787
868686868686868686868686878787878787878787878787878787878787878788888888
888888888888888888888888888888888888888888888888888888888888888887878787
87878787878787878787878787878787868686868686868686868686
848484848484848484848484848585858585858585858585858585858585858585858585
858585858585858585858585858585858585858585858585858585858585858585858585
85858585858585858585858585858584848484848484848484848484
828282828282828282828282828383838383838383838383838383838383838383838383
838383838383838383838383838383838383838383838383838383838383838383838383
83838383838383838383838383838382828282828282828282828282
808080808080808080808080808181818181818181818181818181818181818181818181
818181818181818181818181818181818181818181818181818181818181818181818181
81818181818181818181818181818180808080808080808080808080
7F7F7F7F7F7F7F7F7F7F7F7F7F7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E
7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7F7F7F7F7F7F7F7F7F7F7F7F7F
7D7D7D7D7D7D7D7D7D7D7D7D7D7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C
7C7C7C7C7C7C7C7C7C7C7C7C7C7C7C7D7D7D7D7D7D7D7D7D7D7D7D7D
7B7B7B7B7B7B7B7B7B7B7B7B7B7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A
7A7A7A7A7A7A7A7A7A7A7A7A7A7A7A7B7B7B7B7B7B7B7B7B7B7B7B7B
797979797979797979797979787878787878787878787878787878787878787877777777
777777777777777777777777777777777777777777777777777777777777777778787878
78787878787878787878787878787878797979797979797979797979
787877777777777777777777767676767676767676767676767675757575757575757575
757575757575757575757575757575757575757575757575757575757575757575757575
75757676767676767676767676767676777777777777777777777878
767676767575757575757575747474747474747474747473737373737373737373737373
737373737373737372727272727272727272727273737373737373737373737373737373
73737373737474747474747474747474757575757575757576767676
747474747473737373737373727272727272727272717171717171717171717171717070
707070707070707070707070707070707070707070707070707070707070717171717171
71717171717171727272727272727272737373737373737474747474
73727272727271717171717170707070707070706F6F6F6F6F6F6F6F6F6F6E6E6E6E6E6E
6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6E6F6F
6F6F6F6F6F6F6F6F7070707070707070717171717171727272727273
717170707070706F6F6F6F6F6E6E6E6E6E6E6E6D6D6D6D6D6D6D6D6C6C6C6C6C6C6C6C6C
6C6C6C6C6C6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6B6C6C6C6C6C6C6C6C6C6C6C6C6C
6C6D6D6D6D6D6D6D6D6E6E6E6E6E6E6E6F6F6F6F6F70707070707171
6F6F6F6E6E6E6E6D6D6D6D6D6C6C6C6C6C6C6B6B6B6B6B6B6B6A6A6A6A6A6A6A6A6A6A69
69696969696969696969696969696969696969696969696969696969696A6A6A6A6A6A6A
6A6A6A6B6B6B6B6B6B6B6C6C6C6C6C6C6D6D6D6D6D6E6E6E6E6F6F6F
6D6D6D6C6C6C6C6C6B6B6B6B6A6A6A6A6A69696969696968686868686868686767676767
676767676767676767676767676767676767676767676767676767676767676767686868
68686868686969696969696A6A6A6A6A6B6B6B6B6C6C6C6C6C6D6D6D
6C6B6B6B6A6A6A6A69696969686868686867676767676666666666666665656565656565
656565646464646464646464646464646464646464646464646565656565656565656566
66666666666667676767676868686868696969696A6A6A6A6B6B6B6C
6A6969696968686867676767666666666565656565646464646464636363636363636262
626262626262626262626262626262626262626262626262626262626262636363636363
6364646464646465656565656666666667676767686868696969696A
686867676766666665656565646464646363636362626262626161616161616160606060
6060606060605F5F5F5F5F5F5F5F5F5F5F5F5F5F5F5F6060606060606060606061616161
61616162626262626363636364646464656565656666666767676868
6666656565646464636363636262626161616160606060605F5F5F5F5F5E5E5E5E5E5E5E
5E5D5D5D5D5D5D5D5D5D5D5D5D5D5D5D5D5D5D5D5D5D5D5D5D5D5D5E5E5E5E5E5E5E5E5F
5F5F5F5F606060606061616161626262636363636464646565656666
6464646363636262616161616060605F5F5F5F5E5E5E5E5D5D5D5D5D5C5C5C5C5C5C5B5B
5B5B5B5B5B5B5B5B5B5B5A5A5A5A5A5A5A5A5B5B5B5B5B5B5B5B5B5B5B5B5C5C5C5C5C5C
5D5D5D5D5D5E5E5E5E5F5F5F5F606060616161616262636363646464
6362626161616060605F5F5E5E5E5D5D5D5D5C5C5C5C5B5B5B5B5A5A5A5A5A5959595959
5959595858585858585858585858585858585858585858585859595959595959595A5A5A
5A5A5B5B5B5B5C5C5C5C5D5D5D5D5E5E5E5F5F606060616161626263
616060605F5F5E5E5E5D5D5C5C5C5B5B5B5A5A5A5A595959595858585857575757575757
565656565656565656565656565656565656565656565656565656565757575757575758
585858595959595A5A5A5A5B5B5B5C5C5C5D5D5E5E5E5F5F60606061
5F5F5E5E5D5D5C5C5C5B5B5A5A5A59595958585857575757565656565555555555545454
545454545453535353535353535353535353535353535354545454545454545555555555
56565656575757575858585959595A5A5A5B5B5C5C5C5D5D5E5E5F5F
5D5D5C5C5B5B5A5A5A595958585857575656565555555554545453535353535252525252
525151515151515151515151515151515151515151515151515151525252525252535353
535354545455555555565656575758585859595A5A5A5B5B5C5C5D5D
5B5B5A5A5959585857575756565555555454545353535252525151515150505050504F4F
4F4F4F4F4F4F4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4E4F4F4F4F4F4F4F4F505050505051
5151515252525353535454545555555656575757585859595A5A5B5B
5A59585857575656555555545453535252525151515050504F4F4F4F4E4E4E4E4D4D4D4D
4D4D4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4C4D4D4D4D4D4D4E4E4E4E
4F4F4F4F50505051515152525253535454555555565657575858595A
58575756555554545353525252515150504F4F4F4E4E4E4D4D4D4C4C4C4C4B4B4B4B4B4A
4A4A4A4A4A4A494949494949494949494949494949494A4A4A4A4A4A4A4B4B4B4B4B4C4C
4C4C4D4D4D4E4E4E4F4F4F5050515152525253535454555556575758
5655555454535252515150504F4F4E4E4E4D4D4C4C4C4B4B4B4A4A4A4A49494949484848
48484747474747474747474747474747474747474747474747474848484848494949494A
4A4A4A4B4B4B4C4C4C4D4D4E4E4E4F4F505051515252535454555556
54535352525150504F4F4E4E4D4D4C4C4B4B4B4A4A494949484848474747474646464645
454545454545444444444444444444444444444444444545454545454546464646474747
474848484949494A4A4B4B4B4C4C4D4D4E4E4F4F5050515252535354
52515150504F4E4E4D4D4C4C4B4B4A4A4949484847474746464645454544444444434343
434342424242424242424242424242424242424242424242424243434343434444444445
4545464646474747484849494A4A4B4B4C4C4D4D4E4E4F5050515152
50504F4E4E4D4C4C4B4B4A49494848474746464645454444444343434242424141414141
4040404040403F3F3F3F3F3F3F3F3F3F3F3F3F3F3F3F4040404040404141414141424242
43434344444445454646464747484849494A4B4B4C4C4D4E4E4F5050
4E4E4D4C4C4B4A4A494848474746464545444443434242424141414040403F3F3F3E3E3E
3E3E3D3D3D3D3D3D3D3D3D3D3C3C3C3C3D3D3D3D3D3D3D3D3D3D3E3E3E3E3E3F3F3F4040
40414141424242434344444545464647474848494A4A4B4C4C4D4E4E
4C4C4B4A4A4948484746464545444343424241414040403F3F3E3E3E3D3D3D3C3C3C3C3B
3B3B3B3B3B3A3A3A3A3A3A3A3A3A3A3A3A3A3A3A3A3A3A3B3B3B3B3B3B3C3C3C3C3D3D3D
3E3E3E3F3F4040404141424243434445454646474848494A4A4B4C4C
4A4A494848474645454444434242414140403F3F3E3E3D3D3C3C3C3B3B3B3A3A3A393939
393938383838383838373737373737373737373838383838383839393939393A3A3A3B3B
3B3C3C3C3D3D3E3E3F3F404041414242434444454546474848494A4A
494847464545444343424141403F3F3E3E3D3D3C3C3B3B3A3A3A39393838383737373736
363636363535353535353535353535353535353535353535363636363637373737383838
39393A3A3A3B3B3C3C3D3D3E3E3F3F40414142434344454546474849
474645444343424140403F3E3E3D3D3C3B3B3A3A39393838373737363636353535343434
343333333333333232323232323232323232323232333333333333343434343535353636
36373737383839393A3A3B3B3C3D3D3E3E3F40404142434344454647
454443424141403F3E3E3D3C3C3B3A3A3939383737363635353534343333333232323131
31313130303030303030302F2F2F2F2F2F30303030303030303131313131323232333333
3434353535363637373839393A3A3B3C3C3D3E3E3F40414142434445
434241403F3E3E3D3C3B3B3A39393837373636353434333333323231313030302F2F2F2F
2E2E2E2E2E2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2E2E2E2E2E2F2F2F2F30303031
313232333333343435363637373839393A3B3B3C3D3E3E3F40414243
41403F3E3D3C3B3B3A39383837363635343433333232313130302F2F2E2E2E2D2D2D2C2C
2C2C2B2B2B2B2B2A2A2A2A2A2A2A2A2A2A2A2A2A2A2B2B2B2B2B2C2C2C2C2D2D2D2E2E2E
2F2F30303131323233333434353636373838393A3B3B3C3D3E3F4041
3F3E3D3C3B3A3938383736353534333332313130302F2F2E2E2D2D2C2C2B2B2B2A2A2A29
29292928282828282828282727272727272828282828282828292929292A2A2A2B2B2B2C
2C2D2D2E2E2F2F3030313132333334353536373838393A3B3C3D3E3F
3C3C3B3A393837363535343332323130302F2E2E2D2D2C2B2B2A2A2A2929282828272727
262626262625252525252525252525252525252525252526262626262727272828282929
2A2A2A2B2B2C2D2D2E2E2F303031323233343535363738393A3B3C3C
3A3938383736353433323131302F2E2E2D2C2C2B2B2A2929282827272726262525252424
242423232323232222222222222222222222222222232323232324242424252525262627
2727282829292A2B2B2C2C2D2E2E2F3031313233343536373838393A
383736353433333231302F2E2E2D2C2B2B2A292928272726262525242423232322222221
2121212020202020201F1F1F1F1F1F1F1F1F1F2020202020202121212122222223232324
242525262627272829292A2B2B2C2D2E2E2F30313233333435363738
363534333231302F2F2E2D2C2B2A2A2928272726262524242323222221212020201F1F1F
1E1E1E1E1D1D1D1D1D1D1D1D1C1C1C1C1D1D1D1D1D1D1D1D1E1E1E1E1F1F1F2020202121
222223232424252626272728292A2A2B2C2D2E2F2F30313233343536
34333231302F2E2D2C2B2A2A2928272626252424232222212120201F1F1E1E1D1D1D1C1C
1C1B1B1B1B1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1B1B1B1B1C1C1C1D1D1D1E1E1F
1F2020212122222324242526262728292A2A2B2C2D2E2F3031323334
3231302F2E2D2C2B2A292827262525242322222120201F1F1E1D1D1C1C1B1B1B1A1A1919
1919181818181717171717171717171717171717171718181818191919191A1A1B1B1B1C
1C1D1D1E1F1F202021222223242525262728292A2B2C2D2E2F303132
302F2E2C2B2A2928272626252423222121201F1E1E1D1C1C1B1B1A1A1919181817171716
161615151515151414141414141414141414141414151515151516161617171718181919
1A1A1B1B1C1C1D1E1E1F2021212223242526262728292A2B2C2E2F30
2E2C2B2A29282726252423222120201F1E1D1D1C1B1A1A19191817171616151515141414
131313121212121211111111111111111111111112121212121313131414141515151616
17171819191A1A1B1C1D1D1E1F20202122232425262728292A2B2C2E
2B2A292827262524232221201F1E1D1C1B1B1A1918181716161515141413131212111111
101010100F0F0F0F0F0E0E0E0E0E0E0E0E0E0E0F0F0F0F0F101010101111111212131314
1415151616171818191A1B1B1C1D1E1F202122232425262728292A2B
2928272624232221201F1E1D1C1B1B1A1918171716151414131312111110100F0F0F0E0E
0E0D0D0D0C0C0C0C0C0C0C0B0B0B0B0B0B0C0C0C0C0C0C0C0D0D0D0E0E0E0F0F0F101011
1112131314141516171718191A1B1B1C1D1E1F202122232426272829
272624232221201F1E1D1C1B1A191817161515141312121110100F0F0E0E0D0D0C0C0B0B
0B0A0A0A0A0909090909090908080808090909090909090A0A0A0A0B0B0B0C0C0D0D0E0E
0F0F101011121213141515161718191A1B1C1D1E1F20212223242627
24232221201E1D1C1B1A1918171615141413121110100F0E0E0D0C0C0B0B0A0A09090808
08070707070606060606060606050506060606060606060707070708080809090A0A0B0B
0C0C0D0E0E0F1010111213141415161718191A1B1C1D1E2021222324
2221201E1D1C1B1A191817151514131211100F0E0E0D0C0B0B0A0A090808070706060605
050404040403030303030303030303030303030303030304040404050506060607070808
090A0A0B0B0C0D0E0E0F101112131415151718191A1B1C1D1E202122
201E1D1C1B1A1817161514131211100F0E0D0C0C0B0A0909080707060505040403030302
020201010100000000000000000000000000000000000001010102020203030304040505
0607070809090A0B0C0C0D0E0F1011121314151617181A1B1C1D1E20
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00X@3oool2000000030?ooo`00
0000000007X0oooo002R0?ooo`030000003oool0000007/0oooo002S0?ooo`030000003oool0oooo
07X0oooo002Q0?ooo`80000000<0oooo000000000000NP3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool002l0oooo1@00000a0?ooo`800000
103oool2000000@0oooo0P00000`0?ooo`800000<`3oool2000000@0oooo0P0000040?ooo`800000
<P3oool5000000<0oooo000a0?ooo`030000003oool0oooo0300oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000^0?ooo`040000003oool0oooo00000340oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000c0?ooo`030000003oool0oooo00<0oooo000a
0?ooo`030000003oool0oooo0300oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?oo
o`0/0?ooo`040000003oool0oooo00000340oooo00@000000?ooo`3oool000002`3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo00<0oooo000Y0?ooo`@00000103oool00`000000oooo
0?ooo`0Z0?ooo`@000000P3oool010000000oooo0?ooo`0000090?ooo`800000;`3oool010000000
oooo0?ooo`00000a0?ooo`040000003oool0oooo000000T0oooo0P00000d0?ooo`030000003oool0
oooo00<0oooo000a0?ooo`030000003oool0oooo0300oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0?ooo`0^0?ooo`040000003oool0oooo00000340oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00<0oooo000`0?ooo`800000<`3o
ool2000000X0oooo0`00000_0?ooo`800000<`3oool2000000X0oooo0`00000b0?ooo`8000001@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool002T0oooomP0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000040oooo000Y0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0>03oool01@000000oooo0?ooo`3oool0
00000040oooo000Q0?ooo`D000000`3oool00`000000oooo0?ooo`3b0?ooo`4000000@3oool002<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3b0?ooo`4000000@3oool002<0oooo
00<000000?ooo`3oool00`3oool300000?40oooo0P0000010?ooo`006`3oool4000000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`80gmoO0`3QhN420>;RhP80hn?S0`3T
i>@20>GUi@<0inOW0P3Xj>P20>WYj@<0j^[Z0P3[jn/20>c/k0<0kNg]0P3^k^h20>o_k`<0l?3`0P3a
lO420?;blPD0lo?c0`3dm?@20?Gem@D0m_Kf0P3gmoL50?Shn080nOWi1@3jn_X50?_kn`L0o?cl1`3m
oOd70?knoRX0oooo1`3no_h70?gmo@L0o?cl1@3kno/50?[jnP80nOWi1@3hn?P20?Ogm`D0m_Kf0P3e
mOD30?Cdm0D0lo?c0P3bl_820?7al@<0l?3`0P3_knl20>k^kP<0kNg]0P3/k>`20>_[j`<0j^[Z0P3Y
jNT20>SXj0<0inOW0P3UiND30>CTi080hn?S0P3Rh^830>7Qh@80gmoO103oool100000040oooo000S
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool20=oOg`<0hN7Q0P3Rh^82
0>?Sh`<0i>CT0P3UiND30>OWi`80j>SX0P3YjNT30>[ZjP80jn_[0P3/k>`30>g]k@80k^k^0P3_knl3
0?3`l080lO7a0P3bl_850??cl`<0m?Cd0P3emOD50?KfmP80moOg1@3hn?P20?Win@D0n_[j1@3kno/7
0?clo0L0oOgm1`3no_hZ0?ooo`L0o_kn1`3moOd70?clo0D0no_k1@3jn_X20?Win@D0n?Sh0P3gmoL5
0?KfmP80mOGe0`3dm?@50??cl`80l_;b0P3alO430?3`l080kno_0P3^k^h30>g]k@80k>c/0P3[jn/3
0>[ZjP80jNWY0P3Xj>P30>OWi`80iNGU0`3Ti>@20>?Sh`80h^;R0`3QhN420=oOg`@0oooo0@000001
0?ooo`008P3oool2000000D0oooo00<000000?ooo`3oool00P3oool20=gMg@<0g]kN0P3Ogml20>7Q
h@<0h^;R0P3Shn<30>CTi080iNGU0P3Vi^H30>OWi`80j>SX1@3Zj^X20>_[j`80k>c/0`3]kNd20>k^
kP80kno_0`3`l?050?7al@80l_;b0P3clo<50?Cdm0D0mOGe0P3fm_H50?Ogm`D0n?Sh1`3inOT40?[j
nPX0no_k:P3lo?`:0?_kn`@0n_[j1`3inOT50?Shn0D0moOg0P3fm_H50?Gem@D0m?Cd0P3clo<20?;b
lPD0lO7a0`3`l?020>o_k`80k^k^0`3]kNd20>c/k080jn_[1@3Zj^X20>SXj0<0inOW0P3Vi^H20>GU
i@<0i>CT0P3Shn<30>;RhP80hN7Q0P3Ogml30=kNgP80gMgM103oool100000040oooo000Y0?ooo`03
0000003oool0oooo0080oooo0P3MgMd30=kNgP80gmoO0P3QhN430>;RhP80hn?S0`3Ti>@20>GUi@80
i^KV0`3WinL20>SXj0D0j^[Z0P3[jn/20>c/k0<0kNg]0P3^k^h20>o_k`<0l?3`1@3alO420?;blP80
lo?c1@3dm?@50?Gem@80m_Kf1@3gmoL50?Shn0L0nOWi103jn_X:0?_knbX0o?cl2P3kno/40?[jnPL0
nOWi1@3hn?P50?Ogm`80m_Kf1@3emOD50?Cdm080lo?c0P3bl_850?7al@<0l?3`0P3_knl20>k^kP<0
kNg]0P3/k>`20>_[j`D0j^[Z0P3Xj>P30>OWi`80i^KV0P3UiND30>CTi080hn?S0`3Rh^820>7Qh@80
gmoO0`3Ng]h20=gMg@@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`80gMgM
0`3Ng]h20=oOg`80hN7Q0`3Rh^820>?Sh`<0i>CT0P3UiND20>KViP<0inOW0P3Xj>P50>[ZjP80jn_[
0P3/k>`30>g]k@80k^k^0P3_knl30?3`l0D0lO7a0P3bl_820??cl`D0m?Cd1@3emOD20?KfmPD0moOg
1@3hn?P70?Win@@0n_[j2P3kno/Z0?clo0X0no_k103jn_X70?Win@D0n?Sh1@3gmoL20?KfmPD0mOGe
1@3dm?@20??cl`80l_;b1@3alO430?3`l080kno_0P3^k^h30>g]k@80k>c/0P3[jn/50>[ZjP80j>SX
0`3WinL20>KViP80iNGU0`3Ti>@20>?Sh`<0h^;R0P3QhN420=oOg`<0g]kN0P3MgMd40?ooo`400000
0@3oool002T0oooo00<000000?ooo`3oool00P3oool20=_Kf`<0g=cL0P3MgMd20=kNgP<0gmoO0P3Q
hN430>;RhP80hn?S0P3Ti>@30>GUi@80i^KV0P3WinL30>SXj080jNWY0P3Zj^X50>_[j`80k>c/0`3]
kNd20>k^kPD0kno_0P3`l?050?7al@80l_;b1@3clo<50?Cdm0D0mOGe103fm_H70?Ogm`X0n?Sh4`3i
nOT40?[jnQ<0nOWi2P3hn?P70?Ogm`@0m_Kf1@3emOD50?Cdm0D0lo?c0P3bl_850?7al@80l?3`1@3_
knl20>k^kP<0kNg]0P3/k>`50>_[j`80j^[Z0P3YjNT30>SXj080inOW0P3Vi^H30>GUi@80i>CT0P3S
hn<30>;RhP80hN7Q0`3Ogml20=kNgP80gMgM0`3Lg=`20=_Kf`@0oooo0@0000010?ooo`00:@3oool0
0`000000oooo0?ooo`020?ooo`80fm_K0`3Lg=`20=gMg@80g]kN0`3Ogml20>7Qh@<0h^;R0P3Shn<2
0>CTi0<0iNGU0P3Vi^H20>OWi`<0j>SX0P3YjNT20>[ZjPD0jn_[0P3/k>`30>g]k@80k^k^1@3_knl2
0?3`l0D0lO7a0P3bl_850??cl`D0m?Cd1@3emOD40?KfmPL0moOg2P3hn?PC0?Win@@0n_[j4`3inOT:
0?Shn0L0moOg103fm_H50?Gem@D0m?Cd1@3clo<20?;blPD0lO7a0P3`l?050>o_k`80k^k^0`3]kNd2
0>c/k0D0jn_[0P3Zj^X20>WYj@<0j>SX0P3WinL20>KViP<0iNGU0P3Ti>@20>?Sh`<0h^;R0P3QhN43
0=oOg`80g]kN0P3MgMd30=cLg080fm_K103oool100000040oooo000Y0?ooo`030000003oool0oooo
0080oooo0P3Hf=P30=WIf@80fm_K0P3Lg=`30=gMg@80g]kN0`3Ogml20>3Ph080hN7Q0`3Rh^820>?S
h`80i>CT0`3UiND20>KViP80inOW0`3Xj>P20>WYj@D0j^[Z0P3[jn/30>c/k0@0kNg]0`3^k^h40>o_
k`D0l?3`1@3alO450?;blP@0lo?c1`3dm?@:0?GemA00m_Kf2P3gmoL@0?KfmPX0mOGe1`3dm?@40??c
l`D0l_;b1@3alO450?3`l0@0kno_0`3^k^h40>g]k@<0k>c/0P3[jn/50>[ZjP80jNWY0`3Xj>P20>OW
i`80i^KV0`3UiND20>CTi080hn?S0`3Rh^820>7Qh@80h>3P0`3Ogml20=kNgP<0gMgM0P3Lg=`20=_K
f`<0fMWI0P3Hf=P40?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool20=SHf0<0
fMWI0P3Kfm/20=cLg0<0gMgM0P3Ng]h30=oOg`80h>3P0P3QhN430>;RhP80hn?S0P3Ti>@30>GUi@80
i^KV0P3WinL30>SXj080jNWY1@3Zj^X20>_[j`<0k>c/103]kNd30>k^kP@0kno_1@3`l?050?7al@D0
l_;b103clo<70?Cdm0X0mOGe403fm_H:0?Ogma00m_Kf2P3emOD70?Cdm0@0lo?c1@3bl_850?7al@D0
l?3`103_knl30>k^kP@0kNg]0`3/k>`20>_[j`D0j^[Z0P3YjNT30>SXj080inOW0P3Vi^H30>GUi@80
i>CT0P3Shn<30>;RhP80hN7Q0P3Ph>030=oOg`80g]kN0`3MgMd20=cLg080fm_K0`3IfMT20=SHf0@0
oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`80e]KF0`3GemL20=SHf080fMWI
0`3Kfm/20=cLg0<0gMgM0P3Ng]h20=oOg`<0h>3P0P3QhN420>;RhP<0hn?S103Ti>@30>GUi@80i^KV
0P3WinL50>SXj0<0jNWY0P3Zj^X50>_[j`@0k>c/0`3]kNd40>k^kPD0kno_1`3`l?070?7al@L0l_;b
4@3clo<>0?Cdm140lo?c1`3bl_870?7al@L0l?3`1@3_knl40>k^kP<0kNg]103/k>`50>_[j`80j^[Z
0`3YjNT50>SXj080inOW0P3Vi^H30>GUi@@0i>CT0`3Shn<20>;RhP80hN7Q0`3Ph>020=oOg`80g]kN
0`3MgMd20=cLg0<0fm_K0P3IfMT20=SHf0<0emOG0P3Fe]H40?ooo`4000000@3oool002T0oooo00<0
00000?ooo`3oool00P3oool20=KFeP<0emOG0P3Hf=P20=WIf@<0fm_K0P3Lg=`30=gMg@80g]kN0P3O
gml30>3Ph080hN7Q0P3Rh^830>?Sh`@0i>CT0`3UiND20>KViP80inOW1@3Xj>P30>WYj@80j^[Z1@3[
jn/40>c/k0<0kNg]103^k^h50>o_k`L0l?3`1`3alO470?;blQ40lo?c3P3dm?@A0??cl`L0l_;b1`3a
lO470?3`l0D0kno_103^k^h30>g]k@@0k>c/1@3[jn/20>[ZjP<0jNWY1@3Xj>P20>OWi`80i^KV0`3U
iND40>CTi0<0hn?S0P3Rh^820>7Qh@<0h>3P0P3Ogml20=kNgP<0gMgM0P3Lg=`30=_Kf`80fMWI0P3H
f=P30=OGe`80e]KF103oool100000040oooo000Y0?ooo`8000000`3oool20=KFeP<0emOG0P3Hf=P2
0=WIf@<0fm_K0P3Lg=`30=gMg@80g]kN0P3Ogml30>3Ph080hN7Q0P3Rh^830>?Sh`@0i>CT0`3UiND2
0>KViP80inOW1@3Xj>P30>WYj@80j^[Z1@3[jn/40>c/k0<0kNg]103^k^h50>o_k`L0l?3`1`3alO47
0?;blQ40lo?c3P3dm?@A0??cl`L0l_;b1`3alO470?3`l0D0kno_103^k^h30>g]k@@0k>c/1@3[jn/2
0>[ZjP<0jNWY1@3Xj>P20>OWi`80i^KV0`3UiND40>CTi0<0hn?S0P3Rh^820>7Qh@<0h>3P0P3Ogml2
0=kNgP<0gMgM0P3Lg=`30=_Kf`80fMWI0P3Hf=P30=OGe`80e]KF0`3oool200000040oooo000Y0?oo
o`030000003oool0oooo0080oooo0P3De=@30=GEe@80e]KF0P3GemL30=SHf080fMWI0`3Jf]X20=_K
f`80g=cL0`3MgMd20=kNgP80gmoO0`3Ph>020>7Qh@80h^;R0`3Shn<40>CTi0<0iNGU0P3Vi^H50>OW
i`80j>SX1@3YjNT50>[ZjP@0jn_[1@3/k>`50>g]k@L0k^k^2@3_knl<0?3`l1P0lO7a303`l?090>o_
k`L0k^k^1@3]kNd50>c/k0@0jn_[1@3Zj^X50>WYj@80j>SX1@3WinL20>KViP<0iNGU103Ti>@30>?S
h`80h^;R0P3QhN430>3Ph080gmoO0P3Ng]h30=gMg@80g=cL0P3Kfm/30=[JfP80fMWI0`3Hf=P20=OG
e`80e]KF0`3EeMD20=CDe0@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`80
e=CD0`3EeMD20=KFeP80emOG0`3Hf=P20=WIf@<0f][J0P3Kfm/20=cLg0<0gMgM0P3Ng]h20=oOg`<0
h>3P0P3QhN420>;RhP<0hn?S103Ti>@30>GUi@80i^KV1@3WinL20>SXj0D0jNWY1@3Zj^X40>_[j`D0
k>c/1@3]kNd70>k^kPT0kno_303`l?0H0?7al@`0l?3`2@3_knl70>k^kPD0kNg]1@3/k>`40>_[j`D0
j^[Z1@3YjNT20>SXj0D0inOW0P3Vi^H30>GUi@@0i>CT0`3Shn<20>;RhP80hN7Q0`3Ph>020=oOg`80
g]kN0`3MgMd20=cLg080fm_K0`3Jf]X20=WIf@<0f=SH0P3GemL20=KFeP<0eMGE0P3De=@40?ooo`40
00000@3oool002T0oooo00<000000?ooo`3oool00P3oool20=7Ad@<0dm?C0P3De=@20=GEe@<0e]KF
0P3GemL30=SHf080fMWI0P3Jf]X30=_Kf`80g=cL0P3MgMd30=kNgP@0gmoO0`3Ph>020>7Qh@D0h^;R
0P3Shn<30>CTi0@0iNGU1@3Vi^H20>OWi`D0j>SX1@3YjNT70>[ZjPL0jn_[1`3/k>`<0>g]kA`0k^k^
303]kNd70>c/k0L0jn_[1`3Zj^X50>WYj@D0j>SX0P3WinL50>KViP@0iNGU0`3Ti>@20>?Sh`D0h^;R
0P3QhN430>3Ph0@0gmoO0`3Ng]h20=gMg@80g=cL0`3Kfm/20=[JfP80fMWI0`3Hf=P20=OGe`<0e]KF
0P3EeMD20=CDe0<0dm?C0P3AdM440?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3o
ool20=7Ad@<0dm?C0P3De=@20=GEe@<0e]KF0P3GemL30=SHf080fMWI0P3Jf]X30=_Kf`80g=cL0P3M
gMd30=kNgP@0gmoO0`3Ph>020>7Qh@D0h^;R0P3Shn<30>CTi0@0iNGU1@3Vi^H20>OWi`D0j>SX1@3Y
jNT70>[ZjPL0jn_[1`3/k>`<0>g]kA`0k^k^303]kNd70>c/k0L0jn_[1`3Zj^X50>WYj@D0j>SX0P3W
inL50>KViP@0iNGU0`3Ti>@20>?Sh`D0h^;R0P3QhN430>3Ph0@0gmoO0`3Ng]h20=gMg@80g=cL0`3K
fm/20=[JfP80fMWI0`3Hf=P20=OGe`<0e]KF0P3EeMD20=CDe0<0dm?C0P3AdM440?ooo`4000000@3o
ool002T0oooo00<000000?ooo`3oool00P3oool20<o?c`<0d=3@0P3AdM420=?Cd`<0e=CD0P3EeMD3
0=KFeP80emOG0P3Hf=P50=WIf@80f][J0`3Kfm/20=cLg080gMgM1@3Ng]h20=oOg`<0h>3P1@3QhN42
0>;RhPD0hn?S103Ti>@50>GUi@D0i^KV1@3WinL70>SXj0L0jNWY2`3Zj^XR0>_[j`/0j^[Z1`3YjNT7
0>SXj0D0inOW1@3Vi^H50>GUi@@0i>CT1@3Shn<20>;RhPD0hN7Q0`3Ph>020=oOg`D0g]kN0P3MgMd2
0=cLg0<0fm_K0P3Jf]X50=WIf@80f=SH0P3GemL30=KFeP80eMGE0`3De=@20=?Cd`80dM7A0`3@d=02
0<o?c`@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`80clo?0`3@d=020=7A
d@80dm?C0`3De=@20=GEe@<0e]KF0P3GemL20=SHf0D0fMWI0P3Jf]X30=_Kf`80g=cL0P3MgMd50=kN
gP80gmoO0`3Ph>050>7Qh@80h^;R1@3Shn<40>CTi0D0iNGU1@3Vi^H50>OWi`L0j>SX1`3YjNT;0>[Z
jR80jn_[2`3Zj^X70>WYj@L0j>SX1@3WinL50>KViPD0iNGU103Ti>@50>?Sh`80h^;R1@3QhN430>3P
h080gmoO1@3Ng]h20=gMg@80g=cL0`3Kfm/20=[JfPD0fMWI0P3Hf=P20=OGe`<0e]KF0P3EeMD30=CD
e080dm?C0P3AdM430=3@d080clo?103oool100000040oooo000Y0?ooo`030000003oool0oooo0080
oooo0P3?cll30=3@d080dM7A0P3Cdm<30=CDe080eMGE0`3Fe]H20=OGe`80f=SH1@3IfMT20=[JfP<0
fm_K0P3Lg=`20=gMg@D0g]kN0P3Ogml30>3Ph0D0hN7Q0P3Rh^850>?Sh`@0i>CT1@3UiND50>KViPD0
inOW1`3Xj>P70>WYj@/0j^[Z8P3[jn/;0>[ZjPL0jNWY1`3Xj>P50>OWi`D0i^KV1@3UiND40>CTi0D0
hn?S0P3Rh^850>7Qh@<0h>3P0P3Ogml50=kNgP80gMgM0P3Lg=`30=_Kf`80f][J1@3IfMT20=SHf080
emOG0`3Fe]H20=GEe@<0e=CD0P3Cdm<20=7Ad@<0d=3@0P3?cll40?ooo`4000000@3oool002T0oooo
00<000000?ooo`3oool00P3oool20<g=c@<0c/k>0P3?cll20=3@d0<0dM7A0P3Bd]830=?Cd`80e=CD
0P3EeMD30=KFeP80emOG0P3Hf=P30=WIf@@0f][J0`3Kfm/20=cLg0D0gMgM0P3Ng]h50=oOg`D0h>3P
0P3QhN450>;RhP@0hn?S203Ti>@40>GUi@X0i^KV2@3WinLV0>SXj0T0inOW2P3Vi^H40>GUi@P0i>CT
103Shn<50>;RhP80hN7Q1@3Ph>050=oOg`80g]kN1@3MgMd20=cLg0<0fm_K103Jf]X30=WIf@80f=SH
0P3GemL30=KFeP80eMGE0P3De=@30=?Cd`80d];B0`3AdM420=3@d080clo?0`3>c/h20<g=c@@0oooo
0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`80cLg=0`3>c/h20<o?c`80d=3@0`3A
dM420=;BdP<0dm?C0P3De=@20=GEe@<0e]KF0P3GemL20=SHf0<0fMWI103Jf]X30=_Kf`80g=cL1@3M
gMd20=kNgPD0gmoO1@3Ph>020>7Qh@D0h^;R103Shn<80>CTi0@0iNGU2P3Vi^H90>OWibH0j>SX2@3W
inL:0>KViP@0iNGU203Ti>@40>?Sh`D0h^;R0P3QhN450>3Ph0D0gmoO0P3Ng]h50=gMg@80g=cL0`3K
fm/40=[JfP<0fMWI0P3Hf=P20=OGe`<0e]KF0P3EeMD20=CDe0<0dm?C0P3Bd]830=7Ad@80d=3@0P3?
cll30<k>cP80cLg=103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo0P3;bl/3
0<c<c080cLg=0P3>c/h30<o?c`80d=3@0`3AdM420=;BdP80dm?C0`3De=@40=GEe@<0e]KF0P3GemL2
0=SHf0D0fMWI0P3Jf]X50=_Kf`<0g=cL103MgMd50=kNgPD0gmoO103Ph>050>7Qh@L0h^;R1`3Shn<:
0>CTi2X0iNGU2P3Ti>@70>?Sh`L0h^;R1@3QhN440>3Ph0D0gmoO1@3Ng]h40=gMg@<0g=cL1@3Kfm/2
0=[JfPD0fMWI0P3Hf=P20=OGe`<0e]KF103EeMD30=CDe080dm?C0P3Bd]830=7Ad@80d=3@0`3?cll2
0<k>cP80cLg=0`3<c<`20<_;b`@0oooo0@0000010?ooo`00:@3oool2000000<0oooo0P3;bl/30<c<
c080cLg=0P3>c/h30<o?c`80d=3@0`3AdM420=;BdP80dm?C0`3De=@40=GEe@<0e]KF0P3GemL20=SH
f0D0fMWI0P3Jf]X50=_Kf`<0g=cL103MgMd50=kNgPD0gmoO103Ph>050>7Qh@L0h^;R1`3Shn<:0>CT
i2X0iNGU2P3Ti>@70>?Sh`L0h^;R1@3QhN440>3Ph0D0gmoO1@3Ng]h40=gMg@<0g=cL1@3Kfm/20=[J
fPD0fMWI0P3Hf=P20=OGe`<0e]KF103EeMD30=CDe080dm?C0P3Bd]830=7Ad@80d=3@0`3?cll20<k>
cP80cLg=0`3<c<`20<_;b`<0oooo0P0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`80
bl_;0`3<c<`20<g=c@80c/k>0`3?cll20=3@d0<0dM7A0P3Bd]820=?Cd`<0e=CD103EeMD30=KFeP80
emOG0P3Hf=P50=WIf@80f][J1@3Kfm/30=cLg0@0gMgM1@3Ng]h50=oOg`@0h>3P1@3QhN470>;RhPL0
hn?S2P3Ti>@Z0>GUi@X0i>CT1`3Shn<70>;RhPD0hN7Q103Ph>050=oOg`D0g]kN103MgMd30=cLg0D0
fm_K0P3Jf]X50=WIf@80f=SH0P3GemL30=KFeP@0eMGE0`3De=@20=?Cd`80d];B0`3AdM420=3@d0<0
clo?0P3>c/h20<g=c@<0c<c<0P3;bl/40?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0
0P3oool20<W9b@<0b/[:0P3;bl/20<c<c0<0cLg=0P3>c/h30<o?c`@0d=3@0`3AdM420=;BdP80dm?C
0`3De=@40=GEe@<0e]KF0P3GemL50=SHf0D0fMWI0P3Jf]X50=_Kf`@0g=cL1@3MgMd50=kNgPL0gmoO
1`3Ph>090>7QhA<0h^;R2P3Shn<C0>;RhPT0hN7Q1`3Ph>070=oOg`D0g]kN1@3MgMd40=cLg0D0fm_K
0P3Jf]X50=WIf@D0f=SH0P3GemL30=KFeP@0eMGE0`3De=@20=?Cd`80d];B0`3AdM440=3@d0<0clo?
0P3>c/h30<g=c@80c<c<0P3;bl/30<[:bP80bLW9103oool100000040oooo000Y0?ooo`030000003o
ool0oooo0080oooo0P39bLT30<[:bP80bl_;0P3<c<`30<g=c@80c/k>0`3?cll40=3@d0<0dM7A0P3B
d]820=?Cd`<0e=CD103EeMD30=KFeP80emOG1@3Hf=P50=WIf@80f][J1@3Kfm/40=cLg0D0gMgM1@3N
g]h70=oOg`L0h>3P2@3QhN4C0>;RhPX0hn?S4`3Rh^890>7Qh@L0h>3P1`3Ogml50=kNgPD0gMgM103L
g=`50=_Kf`80f][J1@3IfMT50=SHf080emOG0`3Fe]H40=GEe@<0e=CD0P3Cdm<20=;BdP<0dM7A103@
d=030<o?c`80c/k>0`3=cLd20<c<c080bl_;0`3:b/X20<W9b@@0oooo0@0000010?ooo`00:@3oool0
0`000000oooo0?ooo`020?ooo`80alO70`38b<P20<W9b@80b/[:0`3;bl/50<c<c080cLg=0P3>c/h3
0<o?c`80d=3@1@3AdM420=;BdP80dm?C1@3De=@20=GEe@D0e]KF0`3GemL40=SHf0D0fMWI1@3Jf]X4
0=_Kf`P0g=cL1`3MgMd90=kNgPh0gmoO603Ph>0>0=oOg`T0g]kN1`3MgMd80=cLg0@0fm_K1@3Jf]X5
0=WIf@@0f=SH0`3GemL50=KFeP80eMGE1@3De=@20=?Cd`80d];B1@3AdM420=3@d0<0clo?0P3>c/h2
0<g=c@D0c<c<0`3;bl/20<[:bP80bLW90`38b<P20<O7a`@0oooo0@0000010?ooo`00:@3oool00`00
0000oooo0?ooo`020?ooo`80alO70`38b<P20<W9b@80b/[:0`3;bl/50<c<c080cLg=0P3>c/h30<o?
c`80d=3@1@3AdM420=;BdP80dm?C1@3De=@20=GEe@D0e]KF0`3GemL40=SHf0D0fMWI1@3Jf]X40=_K
f`P0g=cL1`3MgMd90=kNgPh0gmoO603Ph>0>0=oOg`T0g]kN1`3MgMd80=cLg0@0fm_K1@3Jf]X50=WI
f@@0f=SH0`3GemL50=KFeP80eMGE1@3De=@20=?Cd`80d];B1@3AdM420=3@d0<0clo?0P3>c/h20<g=
c@D0c<c<0`3;bl/20<[:bP80bLW90`38b<P20<O7a`@0oooo0@0000010?ooo`00:@3oool00`000000
oooo0?ooo`020?ooo`80aLG50`36a/H40<O7a`<0b<S80P39bLT30<[:bP80bl_;0P3<c<`30<g=c@@0
c/k>0`3?cll20=3@d0D0dM7A0P3Bd]850=?Cd`D0e=CD0P3EeMD50=KFeP@0emOG1`3Hf=P50=WIf@L0
f][J2P3Kfm/;0=cLg280gMgM2`3Lg=`:0=_Kf`L0f][J1@3IfMT70=SHf0@0emOG1@3Fe]H20=GEe@D0
e=CD1@3Cdm<20=;BdPD0dM7A0P3@d=030<o?c`@0c/k>0`3=cLd20<c<c080bl_;0`3:b/X20<W9b@<0
b<S81037alL30<K6aP80aLG5103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo
0P35aLD30<K6aP@0alO70`38b<P20<W9b@<0b/[:0P3;bl/20<c<c0<0cLg=103>c/h30<o?c`80d=3@
1@3AdM420=;BdPD0dm?C1@3De=@20=GEe@D0e]KF103GemL70=SHf0D0fMWI1`3Jf]X:0=_Kf`/0g=cL
8P3MgMd;0=cLg0X0fm_K1`3Jf]X50=WIf@L0f=SH103GemL50=KFeP80eMGE1@3De=@50=?Cd`80d];B
1@3AdM420=3@d0<0clo?103>c/h30<g=c@80c<c<0P3;bl/30<[:bP80bLW90`38b<P40<O7a`<0a/K6
0P35aLD40?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool20<G5a@<0a/K61037
alL30<S8b080bLW90`3:b/X20<_;b`80c<c<0`3=cLd40<k>cP<0clo?0P3@d=050=7Ad@80d];B1@3C
dm<50=CDe080eMGE1@3Fe]H40=OGe`L0f=SH1@3IfMT70=[JfPX0fm_K2`3Lg=`R0=gMg@/0g=cL2P3K
fm/70=[JfPD0fMWI1`3Hf=P40=OGe`D0e]KF0P3EeMD50=CDe0D0dm?C0P3Bd]850=7Ad@80d=3@0`3?
cll40<k>cP<0cLg=0P3<c<`20<_;b`<0b/[:0P39bLT30<S8b0@0alO70`36a/H20<G5a@@0oooo0@00
00010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`D0`l?30P34a<@20<G5a@<0a/K60P37alL3
0<S8b080bLW91@3:b/X20<_;b`80c<c<1@3=cLd20<k>cPD0clo?0P3@d=050=7Ad@D0d];B0P3Cdm<5
0=CDe0L0eMGE1@3Fe]H70=OGe`L0f=SH303IfMTZ0=[JfP`0fMWI1`3Hf=P70=OGe`D0e]KF1`3EeMD5
0=CDe080dm?C1@3Bd]850=7Ad@80d=3@1@3?cll20<k>cPD0cLg=0P3<c<`20<_;b`D0b/[:0P39bLT3
0<S8b080alO70`36a/H20<G5a@80a<C41@33`l<40?ooo`4000000@3oool002T0oooo00<000000?oo
o`3oool00P3oool50<?3``80a<C40P35aLD30<K6aP80alO70`38b<P20<W9b@D0b/[:0P3;bl/20<c<
c0D0cLg=0P3>c/h50<o?c`80d=3@1@3AdM450=;BdP80dm?C1@3De=@70=GEe@D0e]KF1`3GemL70=SH
f0`0fMWI:P3Jf]X<0=WIf@L0f=SH1`3GemL50=KFePL0eMGE1@3De=@20=?Cd`D0d];B1@3AdM420=3@
d0D0clo?0P3>c/h50<g=c@80c<c<0P3;bl/50<[:bP80bLW90`38b<P20<O7a`<0a/K60P35aLD20<C4
a0D0`l?3103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo0P30`<030<71`@80
`/;20P33`l<30<C4a080aLG50`36a/H40<O7a`<0b<S80P39bLT50<[:bP80bl_;1@3<c<`20<g=c@D0
c/k>1@3?cll40=3@d0D0dM7A1@3Bd]840=?Cd`P0e=CD1`3EeMD90=KFeQ<0emOG3P3Hf=PC0=OGe`T0
e]KF1`3EeMD80=CDe0@0dm?C1@3Bd]850=7Ad@@0d=3@1@3?cll50<k>cP80cLg=1@3<c<`20<_;b`D0
b/[:0P39bLT30<S8b0@0alO70`36a/H20<G5a@<0a<C40P33`l<20<;2`P<0`L710P30`<040?ooo`40
00000@3oool002T0oooo0P0000030?ooo`80`<300`31`L420<;2`P80`l?30`34a<@20<G5a@<0a/K6
1037alL30<S8b080bLW91@3:b/X20<_;b`D0c<c<0P3=cLd50<k>cPD0clo?103@d=050=7Ad@D0d];B
103Cdm<80=CDe0L0eMGE2@3Fe]HC0=OGe`h0f=SH4`3GemL90=KFePL0eMGE203De=@40=?Cd`D0d];B
1@3AdM440=3@d0D0clo?1@3>c/h20<g=c@D0c<c<0P3;bl/50<[:bP80bLW90`38b<P40<O7a`<0a/K6
0P35aLD30<C4a080`l?30P32`/830<71`@80`<300`3oool200000040oooo000Y0?ooo`030000003o
ool0oooo0080oooo0P2n_[h30;no_`80`<300P31`L430<;2`P80`l?31@34a<@20<G5a@<0a/K61037
alL30<S8b0@0bLW90`3:b/X40<_;b`D0c<c<1@3=cLd50<k>cP@0clo?1@3@d=070=7Ad@L0d];B2P3C
dm<;0=CDe280eMGE2`3De=@:0=?Cd`L0d];B1`3AdM450=3@d0@0clo?1@3>c/h50<g=c@D0c<c<103;
bl/30<[:bP@0bLW90`38b<P40<O7a`<0a/K60P35aLD50<C4a080`l?30`32`/820<71`@80`<300`2o
_kl20;jn_P@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`80_[jn0`2o_kl2
0<30`080`L710`32`/820<?3``D0a<C40P35aLD30<K6aP@0alO70`38b<P40<W9b@<0b/[:103;bl/5
0<c<c0D0cLg=1@3>c/h40<o?c`D0d=3@1`3AdM470=;BdPX0dm?C2`3De=@R0=GEe@/0e=CD2P3Cdm<7
0=;BdPL0dM7A1@3@d=040<o?c`D0c/k>1@3=cLd50<c<c0@0bl_;0`3:b/X40<W9b@<0b<S81037alL3
0<K6aP80aLG51@34a<@20<?3``<0`/;20P31`L420<30`0<0_kno0P2n_[h40?ooo`4000000@3oool0
02T0oooo00<000000?ooo`3oool00P3oool20;jn_P<0_kno0P30`<020<71`@<0`/;20P33`l<50<C4
a080aLG50`36a/H40<O7a`<0b<S81039bLT30<[:bP@0bl_;1@3<c<`50<g=c@D0c/k>103?cll50=3@
d0L0dM7A1`3Bd]8:0=?Cd`/0e=CD8P3EeMD;0=CDe0X0dm?C1`3Bd]870=7Ad@D0d=3@103?cll50<k>
cPD0cLg=1@3<c<`40<_;b`<0b/[:1039bLT30<S8b0@0alO70`36a/H20<G5a@D0a<C40P33`l<30<;2
`P80`L710P30`<030;no_`80_[jn103oool100000040oooo000Y0?ooo`030000003oool0oooo0080
oooo0P2l_;`30;fm_@80_[jn0P2o_kl30<30`0D0`L710P32`/820<?3``D0a<C40P35aLD50<K6aP80
alO71@38b<P50<W9b@80b/[:1@3;bl/70<c<c0D0cLg=103>c/h80<o?c`T0d=3@303AdM4Z0=;BdP`0
dM7A2@3@d=080<o?c`@0c/k>1@3=cLd70<c<c0D0bl_;0P3:b/X50<W9b@D0b<S80P37alL50<K6aP80
aLG51@34a<@20<?3``80`/;21@31`L430<30`080_kno0P2n_[h30;fm_@80_;bl103oool100000040
oooo000Y0?ooo`030000003oool0oooo0080oooo0P2l_;`30;fm_@80_[jn0P2o_kl30<30`0D0`L71
0P32`/820<?3``D0a<C40P35aLD50<K6aP80alO71@38b<P50<W9b@80b/[:1@3;bl/70<c<c0D0cLg=
103>c/h80<o?c`T0d=3@303AdM4Z0=;BdP`0dM7A2@3@d=080<o?c`@0c/k>1@3=cLd70<c<c0D0bl_;
0P3:b/X50<W9b@D0b<S80P37alL50<K6aP80aLG51@34a<@20<?3``80`/;21@31`L430<30`080_kno
0P2n_[h30;fm_@80_;bl103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo0P2j
^[X30;^k^`80_;bl0P2m_Kd50;jn_P<0_kno0P30`<050<71`@80`/;21@33`l<20<C4a0D0aLG51036
a/H30<O7a`D0b<S81039bLT70<[:bPD0bl_;1`3<c<`70<g=c@`0c/k>4`3?cll>0=3@d1<0clo?303>
c/h70<g=c@L0c<c<1@3;bl/70<[:bP@0bLW91@38b<P30<O7a`@0a/K61@35aLD20<C4a0D0`l?30P32
`/850<71`@80`<300`2o_kl50;jn_P80_Kfm0P2l_;`30;^k^`80^[Zj103oool100000040oooo000Y
0?ooo`030000003oool0oooo0080oooo0P2j^[X30;^k^`80_;bl0P2m_Kd50;jn_P<0_kno0P30`<05
0<71`@80`/;21@33`l<20<C4a0D0aLG51036a/H30<O7a`D0b<S81039bLT70<[:bPD0bl_;1`3<c<`7
0<g=c@`0c/k>4`3?cll>0=3@d1<0clo?303>c/h70<g=c@L0c<c<1@3;bl/70<[:bP@0bLW91@38b<P3
0<O7a`@0a/K61@35aLD20<C4a0D0`l?30P32`/850<71`@80`<300`2o_kl50;jn_P80_Kfm0P2l_;`3
0;^k^`80^[Zj103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo0P2h^;P30;Vi
^@80^[Zj0P2k^k/50;bl_0<0_Kfm0P2n_[h50;no_`80`<301@31`L440<;2`P<0`l?31034a<@50<G5
a@D0a/K61@37alL70<S8b0L0bLW91`3:b/X90<_;b`h0c<c<8P3=cLd>0<c<c0T0bl_;1`3:b/X70<W9
b@L0b<S81@37alL50<K6aPD0aLG51034a<@30<?3``@0`/;21@31`L420<30`0D0_kno0P2n_[h30;fm
_@D0_;bl0P2k^k/20;Zj^P<0^KVi0P2h^;P40?ooo`4000000@3oool002T0oooo00<000000?ooo`3o
ool00P3oool20;Rh^0<0^KVi0P2j^[X20;^k^`D0_;bl0`2m_Kd20;jn_PD0_kno0P30`<050<71`@@0
`/;20`33`l<40<C4a0D0aLG51@36a/H50<O7a`L0b<S81`39bLT70<[:bPT0bl_;3P3<c<`R0<g=c@h0
c<c<2@3;bl/70<[:bPL0bLW91`38b<P50<O7a`D0a/K61@35aLD40<C4a0<0`l?31032`/850<71`@80
`<301@2o_kl20;jn_P<0_Kfm1@2l_;`20;^k^`80^[Zj0`2i^KT20;Rh^0@0oooo0@0000010?ooo`00
:@3oool00`000000oooo0?ooo`020?ooo`80^;Rh0`2i^KT20;Zj^P80^k^k1@2l_;`30;fm_@80_[jn
1@2o_kl20<30`0D0`L711032`/830<?3``@0a<C41@35aLD50<K6aPD0alO71`38b<P70<W9b@L0b/[:
2@3;bl/>0<c<c280cLg=3P3<c<`90<_;b`L0b/[:1`39bLT70<S8b0D0alO71@36a/H50<G5a@@0a<C4
0`33`l<40<;2`PD0`L710P30`<050;no_`80_[jn0`2m_Kd50;bl_080^k^k0P2j^[X30;Vi^@80^;Rh
103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo0P2f][H30;Ng]`80^;Rh0P2i
^KT50;Zj^P<0^k^k102l_;`30;fm_@@0_[jn0`2o_kl40<30`0D0`L711@32`/850<?3``@0a<C41`35
aLD50<K6aPL0alO72P38b<P;0<W9bC00b/[:2`39bLT:0<S8b0L0alO71@36a/H70<G5a@@0a<C41@33
`l<50<;2`PD0`L711030`<030;no_`@0_[jn0`2m_Kd40;bl_0<0^k^k1@2j^[X20;Vi^@80^;Rh0`2g
]kL20;Jf]P@0oooo0@0000010?ooo`00:@3oool2000000<0oooo0P2f][H30;Ng]`80^;Rh0P2i^KT5
0;Zj^P<0^k^k102l_;`30;fm_@@0_[jn0`2o_kl40<30`0D0`L711@32`/850<?3``@0a<C41`35aLD5
0<K6aPL0alO72P38b<P;0<W9bC00b/[:2`39bLT:0<S8b0L0alO71@36a/H70<G5a@@0a<C41@33`l<5
0<;2`PD0`L711030`<030;no_`@0_[jn0`2m_Kd40;bl_0<0^k^k1@2j^[X20;Vi^@80^;Rh0`2g]kL2
0;Jf]P<0oooo0P0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`D0]KFe0P2f][H50;Ng
]`80^;Rh0`2i^KT40;Zj^PD0^k^k0P2l_;`50;fm_@D0_[jn102o_kl50<30`0D0`L711@32`/870<?3
``L0a<C41`35aLD<0<K6aQ00alO76038b<P@0<O7a``0a/K61`35aLD70<C4a0L0`l?31@32`/850<71
`@D0`<30102o_kl50;jn_PD0_Kfm0P2l_;`50;^k^`@0^[Zj0`2i^KT20;Rh^0D0]kNg0P2f][H50;Fe
]@@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`D0]KFe0P2f][H50;Ng]`80
^;Rh0`2i^KT40;Zj^PD0^k^k0P2l_;`50;fm_@D0_[jn102o_kl50<30`0D0`L711@32`/870<?3``L0
a<C41`35aLD<0<K6aQ00alO76038b<P@0<O7a``0a/K61`35aLD70<C4a0L0`l?31@32`/850<71`@D0
`<30102o_kl50;jn_PD0_Kfm0P2l_;`50;^k^`@0^[Zj0`2i^KT20;Rh^0D0]kNg0P2f][H50;Fe]@@0
oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`D0/k>c0P2d];@50;Fe]@80][Jf
1@2g]kL20;Rh^0D0^KVi1@2j^[X20;^k^`D0_;bl102m_Kd50;jn_PL0_kno1@30`<070<71`@L0`/;2
2P33`l<>0<C4a2X0aLG53P34a<@:0<?3``L0`/;21`31`L450<30`0L0_kno1@2n_[h40;fm_@D0_;bl
0P2k^k/50;Zj^PD0^KVi0P2h^;P50;Ng]`80][Jf1@2e]KD20;Bd]0D0/k>c103oool100000040oooo
000Y0?ooo`030000003oool0oooo0080oooo1@2c/k<20;Bd]0D0]KFe0P2f][H50;Ng]`80^;Rh1@2i
^KT50;Zj^P80^k^k1@2l_;`40;fm_@D0_[jn1`2o_kl50<30`0L0`L711`32`/8:0<?3``h0a<C4:P35
aLD>0<C4a0X0`l?31`32`/870<71`@D0`<301`2o_kl50;jn_P@0_Kfm1@2l_;`20;^k^`D0^[Zj1@2i
^KT20;Rh^0D0]kNg0P2f][H50;Fe]@80];Bd1@2c/k<40?ooo`4000000@3oool002T0oooo00<00000
0?ooo`3oool00P3oool50;>c/`80];Bd1@2e]KD20;Jf]PD0]kNg0P2h^;P50;Vi^@D0^[Zj0P2k^k/5
0;bl_0@0_Kfm1@2n_[h70;no_`D0`<301`31`L470<;2`PX0`l?33P34a<@Z0<G5a@h0a<C42P33`l<7
0<;2`PL0`L711@30`<070;no_`D0_[jn102m_Kd50;bl_080^k^k1@2j^[X50;Vi^@80^;Rh1@2g]kL2
0;Jf]PD0]KFe0P2d];@50;>c/`@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?oo
o`D0/K6a0P2b/[850;>c/`80];Bd1@2e]KD20;Jf]PD0]kNg1@2h^;P40;Vi^@D0^[Zj1@2k^k/50;bl
_0L0_Kfm1`2n_[h70;no_`L0`<303031`L4G0<;2`PX0`l?35`32`/8<0<71`@L0`<301`2o_kl70;jn
_PL0_Kfm1@2l_;`50;^k^`D0^[Zj102i^KT50;Rh^0D0]kNg0P2f][H50;Fe]@80];Bd1@2c/k<20;:b
/PD0/K6a103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo1@2a/K420;:b/PD0
/k>c0P2d];@50;Fe]@80][Jf1@2g]kL50;Rh^0@0^KVi1@2j^[X50;^k^`D0_;bl1`2m_Kd70;jn_PL0
_kno1`30`<0<0<71`AL0`/;22P33`l<G0<;2`P`0`L711`30`<070;no_`L0_[jn1`2m_Kd50;bl_0D0
^k^k1@2j^[X40;Vi^@D0^;Rh1@2g]kL20;Jf]PD0]KFe0P2d];@50;>c/`80/[:b1@2a/K440?ooo`40
00000@3oool002T0oooo00<000000?ooo`3oool00P3oool50:n_[`80/;2`1@2a/K420;:b/PD0/k>c
1@2d];@20;Fe]@D0][Jf102g]kL50;Rh^0L0^KVi1@2j^[X70;^k^`L0_;bl1`2m_Kd<0;jn_Ph0_kno
9P30`<0>0;no_``0_[jn1`2m_Kd70;bl_0L0^k^k1@2j^[X70;Vi^@D0^;Rh102g]kL50;Jf]P80]KFe
1@2d];@50;>c/`80/[:b1@2a/K420;2`/0D0[jn_103oool100000040oooo000Y0?ooo`030000003o
ool0oooo0080oooo1@2_[jl20;2`/0D0/K6a0P2b/[850;>c/`D0];Bd0P2e]KD50;Jf]P@0]kNg1@2h
^;P70;Vi^@D0^[Zj1`2k^k/70;bl_0L0_Kfm302n_[h>0;no_bH0`<303P2o_kl<0;jn_PL0_Kfm1`2l
_;`70;^k^`D0^[Zj1`2i^KT50;Rh^0@0]kNg1@2f][H20;Fe]@D0];Bd1@2c/k<20;:b/PD0/K6a0P2`
/;050:n_[`@0oooo0@0000010?ooo`005P3oool2000000@0oooo0P0000040?ooo`8000001@3oool0
0`000000oooo0?ooo`020?ooo`80[Jf]1@2^[Zh50:n_[`80/;2`1@2a/K450;:b/P@0/k>c1@2d];@5
0;Fe]@@0][Jf1@2g]kL70;Rh^0L0^KVi1`2j^[X:0;^k^``0_;bl>02m_Kd<0;bl_0X0^k^k1`2j^[X7
0;Vi^@L0^;Rh1@2g]kL40;Jf]PD0]KFe1@2d];@40;>c/`D0/[:b1@2a/K420;2`/0D0[jn_1@2^[Zh2
0:f][@@0oooo0@0000010?ooo`005@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00P3oool20:f][@D0[Zj^1@2_[jl20;2`/0D0/K6a1@2b
/[840;>c/`D0];Bd1@2e]KD40;Jf]PD0]kNg1`2h^;P70;Vi^@L0^[Zj2P2k^k/<0;bl_3P0_Kfm302l
_;`:0;^k^`L0^[Zj1`2i^KT70;Rh^0D0]kNg102f][H50;Fe]@D0];Bd102c/k<50;:b/PD0/K6a0P2`
/;050:n_[`D0[Zj^0P2][Jd40?ooo`4000000@3oool001D0oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0?ooo`020?ooo`<000000P3oool20:f][@D0[Zj^1@2_[jl20;2`/0D0/K6a1@2b
/[840;>c/`D0];Bd1@2e]KD40;Jf]PD0]kNg1`2h^;P70;Vi^@L0^[Zj2P2k^k/<0;bl_3P0_Kfm302l
_;`:0;^k^`L0^[Zj1`2i^KT70;Rh^0D0]kNg102f][H50;Fe]@D0];Bd102c/k<50;:b/PD0/K6a0P2`
/;050:n_[`D0[Zj^0P2][Jd30?ooo`8000000@3oool000l0oooo100000020?ooo`040000003oool0
oooo000000T0oooo0P0000050?ooo`030000003oool0oooo0080oooo0P2[Zj/50:b/[0D0[Jf]0P2^
[Zh50:n_[`D0/;2`102a/K450;:b/PD0/k>c1`2d];@50;Fe]@L0][Jf1`2g]kL90;Rh^0X0^KVi402j
^[XV0;^k^a00^[Zj2P2i^KT90;Rh^0L0]kNg1`2f][H50;Fe]@L0];Bd1@2c/k<50;:b/P@0/K6a1@2`
/;050:n_[`80[Zj^1@2][Jd50:b/[080Zj^[103oool100000040oooo000E0?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`80Zj^[1@2/
[:`50:f][@80[Zj^1@2_[jl50;2`/0@0/K6a1@2b/[850;>c/`L0];Bd1@2e]KD70;Jf]PL0]kNg2@2h
^;P:0;Vi^A00^[Zj9P2k^k/@0;Zj^PX0^KVi2@2h^;P70;Ng]`L0][Jf1@2e]KD70;Bd]0D0/k>c1@2b
/[840;6a/@D0/;2`1@2_[jl20:j^[PD0[Jf]1@2/[:`20:^[Z`@0oooo0@0000010?ooo`005P3oool2
000000X0oooo0`0000040?ooo`030000003oool0oooo0080oooo0P2YZJT50:ZZZPD0Zj^[0P2/[:`5
0:f][@D0[Zj^102_[jl50;2`/0L0/K6a1@2b/[870;>c/`L0];Bd2@2e]KD:0;Jf]P`0]kNg>02h^;P<
0;Ng]`X0][Jf2@2e]KD70;Bd]0L0/k>c1@2b/[870;6a/@D0/;2`102_[jl50:j^[PD0[Jf]0P2/[:`5
0:^[Z`D0ZZZZ0P2YZJT40?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool20:VY
Z@D0ZZZZ1@2[Zj/20:b/[0D0[Jf]1@2^[Zh40:n_[`D0/;2`1`2a/K450;:b/PL0/k>c1`2d];@90;Fe
]@X0][Jf302g]kLh0;Rh^0`0]kNg2P2f][H90;Fe]@L0];Bd1`2c/k<50;:b/PL0/K6a1@2`/;040:n_
[`D0[Zj^1@2][Jd20:b/[0D0Zj^[1@2ZZZX20:VYZ@@0oooo0@0000010?ooo`00:@3oool00`000000
oooo0?ooo`020?ooo`80YjNW1@2XZ:P20:VYZ@D0ZZZZ1@2[Zj/50:b/[0L0[Jf]102^[Zh50:n_[`L0
/;2`1`2a/K470;:b/PX0/k>c302d];@@0;Fe]BH0][Jf402e]KD<0;Bd]0X0/k>c1`2b/[870;6a/@L0
/;2`1@2_[jl40:j^[PL0[Jf]1@2/[:`50:^[Z`D0ZZZZ0P2YZJT50:RXZ080YjNW103oool100000040
oooo000Y0?ooo`030000003oool0oooo0080oooo0P2WYjL50:RXZ080ZJVY1@2ZZZX50:^[Z`D0[:b/
1`2][Jd40:j^[PD0[jn_1`2`/;070;6a/@L0/[:b2P2c/k<<0;Bd]100]KFe9P2f][H@0;Fe]@`0];Bd
2P2c/k<70;:b/PL0/K6a1`2`/;050:n_[`@0[Zj^1`2][Jd50:b/[0D0Zj^[1@2ZZZX20:VYZ@D0Z:RX
0P2WYjL40?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool20:NWY`D0Z:RX0P2Y
ZJT50:ZZZPD0Zj^[1@2/[:`70:f][@@0[Zj^1@2_[jl70;2`/0L0/K6a1`2b/[8:0;>c/``0];Bd402e
]KDV0;Jf]Q00]KFe302d];@:0;>c/`L0/[:b1`2a/K470;2`/0D0[jn_102^[Zh70:f][@D0[:b/1@2[
Zj/50:ZZZP80ZJVY1@2XZ:P20:NWY`@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`02
0?ooo`80YJFU0`2VYZH40:NWY`D0Z:RX1@2YZJT70:ZZZPD0Zj^[102/[:`70:f][@P0[Zj^1`2_[jl9
0;2`/0X0/K6a3P2b/[8h0;>c/`h0/[:b2P2a/K490;2`/0L0[jn_202^[Zh70:f][@@0[:b/1@2[Zj/7
0:ZZZPD0ZJVY1@2XZ:P40:NWY`<0YZJV0P2UYJD40?ooo`4000000@3oool002T0oooo00<000000?oo
o`3oool00P3oool20:FUY@<0YZJV102WYjL50:RXZ0D0ZJVY1`2ZZZX50:^[Z`@0[:b/1`2][Jd80:j^
[PL0[jn_2@2`/;0:0;6a/@h0/[:b>02c/k<>0;:b/PX0/K6a2@2`/;070:n_[`P0[Zj^1`2][Jd40:b/
[0D0Zj^[1`2ZZZX50:VYZ@D0Z:RX102WYjL30:JVYP80YJFU103oool100000040oooo000Y0?ooo`03
0000003oool0oooo0080oooo1@2TY:@40:FUY@D0YZJV1@2WYjL70:RXZ0D0ZJVY1`2ZZZX70:^[Z`L0
[:b/1`2][Jd90:j^[P`0[jn_4`2`/;0V0;6a/A<0/;2`302_[jl90:j^[PL0[Jf]1`2/[:`70:^[Z`L0
ZZZZ1@2YZJT70:RXZ0D0YjNW1@2VYZH40:FUY@D0Y:BT103oool100000040oooo000Y0?ooo`800000
0`3oool50:BTY0@0YJFU1@2VYZH50:NWY`L0Z:RX1@2YZJT70:ZZZPL0Zj^[1`2/[:`70:f][@T0[Zj^
302_[jlC0;2`/2H0/K6a4`2`/;0<0:n_[`T0[Zj^1`2][Jd70:b/[0L0Zj^[1`2ZZZX50:VYZ@L0Z:RX
1@2WYjL50:JVYP@0YJFU1@2TY:@30?ooo`8000000@3oool002T0oooo00<000000?ooo`3oool00P3o
ool50:BTY0@0YJFU1@2VYZH50:NWY`L0Z:RX1@2YZJT70:ZZZPL0Zj^[1`2/[:`70:f][@T0[Zj^302_
[jlC0;2`/2H0/K6a4`2`/;0<0:n_[`T0[Zj^1`2][Jd70:b/[0L0Zj^[1`2ZZZX50:VYZ@L0Z:RX1@2W
YjL50:JVYP@0YJFU1@2TY:@40?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool5
0::RXP@0Xj>S1@2TY:@70:FUY@D0YZJV1`2WYjL50:RXZ0L0ZJVY2@2ZZZX70:^[Z``0[:b/3P2][Jdn
0:j^[Ph0[Jf]302/[:`70:^[Z`T0ZZZZ1`2YZJT50:RXZ0L0YjNW1@2VYZH70:FUY@D0Y:BT102SXj<5
0::RXP@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`D0XZ:R102SXj<50:BT
Y0L0YJFU1@2VYZH70:NWY`D0Z:RX1`2YZJT90:ZZZPL0Zj^[302/[:`>0:f][Ch0[Zj^3P2][Jd<0:b/
[0L0Zj^[2@2ZZZX70:VYZ@D0Z:RX1`2WYjL50:JVYPL0YJFU1@2TY:@40:>SX`D0XZ:R103oool10000
0040oooo000Y0?ooo`030000003oool0oooo0080oooo1@2PX:040:6QX@D0XZ:R1`2SXj<50:BTY0L0
YJFU1`2VYZH70:NWY`X0Z:RX2@2YZJT<0:ZZZQ<0Zj^[:P2/[:`C0:^[Z``0ZZZZ2@2YZJT:0:RXZ0L0
YjNW1`2VYZH70:FUY@D0Y:BT1`2SXj<50::RXP@0XJ6Q1@2PX:040?ooo`4000000@3oool002T0oooo
00<000000?ooo`3oool00P3oool50:2PX0@0XJ6Q1@2RXZ870:>SX`D0Y:BT1`2UYJD70:JVYPL0YjNW
2P2XZ:P90:VYZ@`0ZZZZ4`2[Zj/Z0:b/[1<0Zj^[302ZZZX90:VYZ@X0Z:RX1`2WYjL70:JVYPL0YJFU
1@2TY:@70:>SX`D0XZ:R102QXJ450:2PX0@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?oo
o`020?ooo`80WYjN1`2OWil50:2PX0L0XJ6Q1@2RXZ870:>SX`L0Y:BT2P2UYJD90:JVYPT0YjNW4@2X
Z:Q20:VYZA40Z:RX2@2WYjL90:JVYPX0YJFU1`2TY:@70:>SX`D0XZ:R1`2QXJ450:2PX0L0WinO0P2N
WYh40?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool209jNWPL0WinO1@2PX:07
0:6QX@D0XZ:R1`2SXj<70:BTY0X0YJFU2@2VYZH90:NWYa40Z:RX@P2YZJTA0:RXZ0T0YjNW2@2VYZH:
0:FUY@L0Y:BT1`2SXj<50::RXPL0XJ6Q1@2PX:0709nOW`80WYjN103oool100000040oooo000Y0?oo
o`030000003oool0oooo0080oooo0P2NWYh709nOW`D0X:2P1`2QXJ450::RXPL0Xj>S1`2TY:@:0:FU
Y@T0YZJV2@2WYjLA0:RXZ480ZJVY4@2XZ:P90:NWY`T0YZJV2P2UYJD70:BTY0L0Xj>S1@2RXZ870:6Q
X@D0X:2P1`2OWil209jNWP@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`80
W9bL1@2MWId709jNWPL0WinO1@2PX:070:6QX@T0XZ:R2P2SXj<90:BTY0`0YJFU4`2VYZHd0:NWYa<0
YZJV302UYJD90:BTY0X0Xj>S2@2RXZ870:6QX@D0X:2P1`2OWil709jNWPD0WIfM0P2LW9`40?ooo`40
00000@3oool002T0oooo00<000000?ooo`3oool00P3oool209bLW0D0WIfM1`2NWYh709nOW`D0X:2P
1`2QXJ490::RXPX0Xj>S2@2TY:@<0:FUYA<0YZJV=02WYjLC0:JVYP`0YJFU2@2TY:@:0:>SX`T0XZ:R
1`2QXJ450:2PX0L0WinO1`2NWYh509fMW@80W9bL103oool100000040oooo000Y0?ooo`030000003o
ool0oooo0080oooo1`2KVi/709bLW0D0WIfM2@2NWYh709nOW`X0X:2P2@2QXJ4<0::RXPh0Xj>S7@2T
Y:@B0:FUYAd0Y:BT3P2SXj<<0::RXPT0XJ6Q2P2PX:0709nOW`T0WYjN1@2MWId709bLW0L0Vi^K103o
ool100000040oooo000Y0?ooo`8000000`3oool709^KV`L0W9bL1@2MWId909jNWPL0WinO2P2PX:09
0:6QX@`0XZ:R3P2SXj<M0:BTY180YJFU7@2TY:@>0:>SX``0XZ:R2@2QXJ4:0:2PX0L0WinO2@2NWYh5
09fMW@L0W9bL1`2KVi/30?ooo`8000000@3oool002T0oooo00<000000?ooo`3oool00P3oool509VI
V@L0VYZJ1`2KVi/909bLW0L0WIfM2P2NWYh<09nOW`/0X:2P4`2QXJ4n0::RXQ<0XJ6Q2`2PX:0<09nO
W`X0WYjN1`2MWId909bLW0L0Vi^K1`2JVYX509VIV@@0oooo0@0000010?ooo`00:@3oool00`000000
oooo0?ooo`020?ooo`D0VIVI1`2JVYX709^KV`T0W9bL1`2MWId:09jNWP`0WinO2`2PX:0C0:6QXCh0
XZ:R4`2QXJ4;0:2PX0`0WinO2P2NWYh709fMW@T0W9bL1`2KVi/709ZJVPD0VIVI103oool100000040
oooo000Y0?ooo`030000003oool0oooo0080oooo1@2IVIT709ZJVPL0Vi^K2@2LW9`709fMW@X0WYjN
302OWil;0:2PX1<0XJ6Q?P2RXZ8C0:6QX@/0X:2P302OWil:09jNWPL0WIfM2@2LW9`709^KV`L0VYZJ
1@2IVIT40?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool509NGU`L0V9RH1`2I
VIT909ZJVPX0Vi^K2@2LW9`<09fMWA40WYjN5`2OWilV0:2PX1L0WinO4@2NWYh<09fMW@T0W9bL2P2K
Vi/909ZJVPL0VIVI1`2HV9P509NGU`@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`02
0?ooo`D0UiNG1`2HV9P709VIV@T0VYZJ2P2KVi/909bLW0`0WIfM4@2NWYhG09nOWbH0X:2P5`2OWilA
09jNWP`0WIfM2@2LW9`:09^KV`T0VYZJ1`2IVIT709RHV0D0UiNG103oool100000040oooo000Y0?oo
o`030000003oool0oooo0080oooo0P2EUID:09JFUPL0UiNG2@2HV9P:09VIV@`0VYZJ3P2KVi/@09bL
W4`0WIfM402LW9`>09^KV``0VYZJ2P2IVIT909RHV0L0UiNG2P2FUYH209FEU@@0oooo0@0000010?oo
o`00:@3oool00`000000oooo0?ooo`020?ooo`80UIFE2P2FUYH709NGU`T0V9RH2P2IVIT<09ZJVPh0
Vi^K402LW9a<09fMWA00W9bL3P2KVi/<09ZJVPX0VIVI2@2HV9P709NGU`X0UYJF0P2EUID40?ooo`40
00000@3oool002T0oooo00<000000?ooo`3oool00P3oool209>CT`L0U9BD2P2EUID909JFUP`0UiNG
302HV9P@09VIVAP0VYZJ=02KVi/H09ZJVQ00VIVI302HV9P<09NGU`T0UYJF2P2EUID709BDU080Ti>C
103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo0P2CTi<709BDU0X0UIFE2@2F
UYH<09NGU``0V9RH402IVITH09ZJVS@0Vi^K602JVYX@09VIV@`0V9RH302GUiL909JFUPX0UIFE1`2D
U9@209>CT`@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`80Ti>C1`2DU9@:
09FEU@T0UYJF302GUiL<09RHV100VIVI602JVYXd09^KVaP0VYZJ402IVIT<09RHV0`0UiNG2@2FUYH:
09FEU@L0U9BD0P2CTi<40?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool709:B
TP`0Ti>C2@2DU9@<09FEU@h0UYJF4`2GUiMJ09RHV1<0UiNG3P2FUYH<09FEU@T0U9BD302CTi<709:B
TP@0oooo0@0000010?ooo`00:@3oool2000000<0oooo1`2BTY8<09>CT`T0U9BD302EUID>09JFUQ<0
UiNGFP2HV9PC09NGU`h0UYJF302EUID909BDU0`0Ti>C1`2BTY830?ooo`8000000@3oool002T0oooo
00<000000?ooo`3oool00P3oool7092@T0X0TI6A2`2BTY8>09>CTa40U9BD602EUIE609JFUQP0UIFE
4@2DU9@>09>CT`/0TY:B2P2ATI47092@T0@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?oo
o`020?ooo`L0T92@2P2ATI4;09:BTPh0Ti>C4@2DU9@H09FEUDH0UYJF602EUIDA09BDU0h0Ti>C2`2B
TY8:096AT@L0T92@103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo1@2>SXh<
08n?S`/0T92@4@2ATI4C09:BTR40Ti>C:P2DU9@Q09>CTa<0TY:B4@2ATI4;092@T0`0Shn?1@2>SXh4
0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool508j>SP`0Shn?2`2@T90A096A
TA<0TY:B8@2CTi<Z09BDU240Ti>C4`2BTY8A096AT@/0T92@302?Shl508j>SP@0oooo0@0000010?oo
o`00:@3oool00`000000oooo0?ooo`020?ooo`D0SXj>302?Shl;092@T140TI6A4`2BTY8Q09>CTbX0
U9BD8@2CTi<C09:BTQ40TI6A2`2@T90<08n?S`D0SXj>103oool100000040oooo000Y0?ooo`030000
003oool0oooo0080oooo0P2<S8`<08f=S@h0SXj>4`2?ShlH092@T5h0TI6A602@T90C08n?S`h0SXj>
302=SHd208b<S0@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`80S8b<302=
SHd>08j>SQ<0Shn?602@T91N096ATAP0T92@4`2?Shl>08j>SP`0SHf=0P2<S8`40?ooo`4000000@3o
ool002T0oooo00<000000?ooo`3oool00P3oool<08^;Ra00S8b<5P2=SHdN08j>ST`0Shn?7P2>SXhF
08f=SA00S8b<302;Rh/40?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool<08^;
Ra00S8b<5P2=SHdN08j>ST`0Shn?7P2>SXhF08f=SA00S8b<302;Rh/40?ooo`4000000@3oool002T0
oooo00<000000?ooo`3oool00P3oool908V9RA<0RXZ:6P2;Rh/b08b<S1`0SHf=<P2<S8`J08^;Ra<0
RXZ:2@29RHT40?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool908V9RA<0RXZ:
6P2;Rh/b08b<S1`0SHf=<P2<S8`J08^;Ra<0RXZ:2@29RHT40?ooo`4000000@3oool002T0oooo0P00
00030?ooo`T0RHV94`2:RXXJ08^;Rc80S8b<702=SHdb08b<S1X0Rh^;4`2:RXX908V9R@<0oooo0P00
00010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`D0QhN75`28R8PQ08V9RG80RXZ:8@29RHTG
08R8R0D0QhN7103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo1@27QhLG08R8
R240RHV9LP2:RXXQ08V9RAL0R8R81@27QhL40?ooo`4000000@3oool002T0oooo00<000000?ooo`3o
ool00P3ooolL08J6QS00QhN7E028R8P`08N7Qa`0QXJ6103oool100000040oooo000Y0?ooo`030000
003oool0oooo0080oooo7026QXH`08N7Qe@0R8R8<027QhLL08J6QP@0oooo0@0000010?ooo`00:@3o
ool00`000000oooo0?ooo`020?oooal0Q8B4[P25QHDO08B4Q0@0oooo0@0000010?ooo`00:@3oool0
0`000000oooo0?ooo`020?oooal0Q8B4[P25QHDO08B4Q0@0oooo0@0000010?ooo`00:@3oool00`00
0000oooo0?ooo`020?oooal0Q8B4[P25QHDO08B4Q0@0oooo0@0000010?ooo`00:@3oool00`000000
oooo0?ooo`020?oooal0PX:2[P23Ph<O08:2PP@0oooo0@0000010?ooo`00:@3oool00`000000oooo
0?ooo`020?oooal0PX:2[P23Ph<O08:2PP@0oooo0@0000010?ooo`001@3oool00`000000oooo0?oo
o`0J0?ooo`8000001@3oool00`000000oooo0?ooo`020?oooal0P820[P21PH4O0820P0@0oooo0@00
00010?ooo`001@3oool2000000<0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0080oooo7`20P82^0861PAl0P820103oool100000040oooo0005
0?ooo`040000003oool000000?ooo`8000005P3oool010000000oooo0?ooo`0000040?ooo`<00000
0P3ooolO0820P:h0PH617`20P8030?ooo`8000000@3oool000P0oooo00<000000?ooo`3oool05P3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo7`1oOgn^07inOQl0Ogmo
103oool100000040oooo00050?ooo`<000006@3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0080oooo7`1oOgn^07inOQl0Ogmo103oool100000040oooo00050?ooo`030000003o
ool0oooo01X0oooo0P0000050?ooo`030000003oool0oooo0080oooo7`1mOGf^07alO1l0OGem103o
ool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo7`1mOGf^07alO1l0OGem103oool1
00000040oooo000Y0?ooo`030000003oool0oooo0080oooo7`1kNg^^07YjNQl0Ng]k103oool10000
0040oooo000Y0?ooo`030000003oool0oooo0080oooo7`1kNg^^07YjNQl0Ng]k103oool100000040
oooo000Y0?ooo`030000003oool0oooo0080oooo7`1kNg^^07YjNQl0Ng]k103oool100000040oooo
000Y0?ooo`030000003oool0oooo0080oooo701iNGT`07QhN5@0MgMg<01hN7PL07UiN@@0oooo0@00
00010?ooo`00:@3oool00`000000oooo0?ooo`020?oooa`0NGUi<01hN7QD07MgMc00N7Qh701iNGT4
0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool507QhN1L0MgMg8@1fMWIb07Ee
MB40MWIf5`1gMgL507QhN0@0oooo0@0000010?ooo`00:@3oool2000000<0oooo1@1hN7PG07MgMb40
MWIfLP1eMGDQ07IfMQL0MgMg1@1hN7P30?ooo`8000000@3oool002T0oooo00<000000?ooo`3oool0
0P3oool907IfMQ<0MGEe6P1dM7@b07=cLa`0LW9b<P1cLg<J07AdM1<0MGEe2@1fMWH40?ooo`400000
0@3oool002T0oooo00<000000?ooo`3oool00P3oool907IfMQ<0MGEe6P1dM7@b07=cLa`0LW9b<P1c
Lg<J07AdM1<0MGEe2@1fMWH40?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool9
07IfMQ<0MGEe6P1dM7@b07=cLa`0LW9b<P1cLg<J07AdM1<0MGEe2@1fMWH40?ooo`4000000@3oool0
02T0oooo00<000000?ooo`3oool00P3oool<07AdM100Lg=c5P1bLW8N075aLD`0L71`7P1aLG4F079b
LQ00Lg=c301dM7@40?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool<07AdM100
Lg=c5P1bLW8N075aLD`0L71`7P1aLG4F079bLQ00Lg=c301dM7@40?ooo`4000000@3oool002T0oooo
00<000000?ooo`3oool00P3oool207=cL``0LW9b3P1aLG4C071`L1P0Kfm_GP1^KVhH06m_Ka<0L71`
3P1aLG4<079bLP80Lg=c103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo0P1c
Lg<<079bLPh0LG5a4`1`L70H06m_Keh0KVi^601_KflC071`L0h0LG5a301bLW8207=cL`@0oooo0@00
00010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`D0LG5a301`L70;06m_Ka40KVi^4`1]KFdQ
06a/K2X0Jf][8@1/K6`C06e]KA40KVi^2`1_Kfl<071`L0D0LG5a103oool100000040oooo000Y0?oo
o`030000003oool0oooo0080oooo1@1aLG4<071`L0/0Kfm_4@1^KVhC06e]KB40K6a/:P1[Jf/Q06a/
K1<0KFe]4@1^KVh;06m_K``0L71`1@1aLG440?ooo`4000000@3oool002T0oooo00<000000?ooo`3o
ool00P3oool5075aL@`0L71`2`1_KflA06i^KQ<0KFe]8@1/K6`Z06][Jb40K6a/4`1]KFdA06i^KP/0
Kfm_301`L705075aL@@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`L0Kfm_
2P1^KVh;06e]K@h0K6a/4@1[Jf/H06YZJTH0JFUY601ZJVXA06][J`h0K6a/2`1]KFd:06i^KPL0Kfm_
103oool100000040oooo000Y0?ooo`8000000`3oool706m_K`X0KVi^2`1]KFd>06a/K140Jf][601Z
JVY606UYJAP0JVYZ4@1[Jf/>06a/K0/0KFe]2P1^KVh706m_K`<0oooo0P0000010?ooo`00:@3oool0
0`000000oooo0?ooo`020?ooo`L0KFe]301/K6`906][J``0JVYZ3P1YJFTC06QXJ5X0IfMW4`1XJ6P>
06UYJ@`0JVYZ2@1[Jf/<06a/K0L0KFe]103oool100000040oooo000Y0?ooo`030000003oool0oooo
0080oooo1`1]KFd<06a/K0T0Jf][301ZJVX>06UYJA<0J6QXFP1WIfLC06QXJ0h0JFUY301ZJVX906][
J``0K6a/1`1]KFd40?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool206a/K0L0
Jf][2P1ZJVX906UYJ@`0J6QX301WIfL@06IVIQP0IFEU=01TI6@H06EUIA00IVIV301WIfL<06QXJ0T0
JFUY2P1ZJVX706][J`80K6a/103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo
0P1/K6`706][J`X0JVYZ2@1YJFT<06QXJ0`0IfMW401VIVHH06EUIC@0I6AT601UIFD@06IVIP`0IfMW
301XJ6P906UYJ@X0JVYZ1`1[Jf/206a/K0@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?oo
o`020?ooo`80K6a/1`1[Jf/:06YZJPT0JFUY301XJ6P<06MWIa00IVIV601UIFDd06ATI1P0IFEU401V
IVH<06MWI``0J6QX2@1YJFT:06YZJPL0Jf][0P1/K6`40?ooo`4000000@3oool002T0oooo00<00000
0?ooo`3oool00P3oool206YZJPX0JFUY1`1XJ6P906MWI`X0IVIV301UIFD>06ATI100Hf=SC01RHV8@
06=SH`h0I6AT301UIFD:06IVIPT0IfMW1`1XJ6P:06UYJ@80JVYZ103oool100000040oooo000Y0?oo
o`030000003oool0oooo0080oooo0P1ZJVX:06UYJ@L0J6QX2@1WIfL:06IVIP`0IFEU3P1TI6@@06=S
Hd`0HV9R401SHf<>06ATI0`0IFEU2P1VIVH906MWI`L0J6QX2P1YJFT206YZJP@0oooo0@0000010?oo
o`00:@3oool00`000000oooo0?ooo`020?ooo`D0J6QX1`1WIfL706IVIPT0IFEU2P1TI6@906=SH``0
HV9R4@1QHF4G061PH2H0GemO5`1PH60A065QH@`0HV9R2@1SHf<:06ATI0T0IFEU1`1VIVH706MWI`D0
J6QX103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo1@1XJ6P706MWI`L0IVIV
2@1UIFD:06ATI0T0Hf=S301RHV8A065QHAL0H61P9P1OGelG061PH140HF5Q301RHV8906=SH`X0I6AT
2@1UIFD706IVIPL0IfMW1@1XJ6P40?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3o
ool506IVIPL0IFEU1`1TI6@906=SH`L0HV9R2P1QHF4<061PH0/0GemO4`1NGUhn05eMGA<0GUiN2`1O
Gel<061PH0X0HF5Q1`1RHV8906=SH`L0I6AT1`1UIFD506IVIP@0oooo0@0000010?ooo`00:@3oool0
0`000000oooo0?ooo`020?ooo`D0IVIV1`1UIFD706ATI0T0Hf=S1`1RHV8:065QH@`0H61P2`1OGelC
05iNGSh0GEeM4`1NGUh;05mOG``0H61P2P1QHF47069RHPT0Hf=S1`1TI6@706EUI@D0IVIV103oool1
00000040oooo000Y0?ooo`8000000`3oool506IVIPL0IFEU1`1TI6@906=SH`L0HV9R2P1QHF4<061P
H0/0GemO4`1NGUhn05eMGA<0GUiN2`1OGel<061PH0X0HF5Q1`1RHV8906=SH`L0I6AT1`1UIFD506IV
IP<0oooo0P0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`L0I6AT1`1SHf<5069RHPT0
HF5Q1`1PH60:05mOG`T0GUiN301MGEd>05aLG1d0Fe]K4P1JFUXM05]KF`h0G5aL301MGEd905iNGPX0
GemO1`1PH609065QH@D0HV9R1`1SHf<706ATI0@0oooo0@0000010?ooo`00:@3oool00`000000oooo
0?ooo`020?ooo`L0I6AT1`1SHf<5069RHPT0HF5Q1`1PH60:05mOG`T0GUiN301MGEd>05aLG1d0Fe]K
4P1JFUXM05]KF`h0G5aL301MGEd905iNGPX0GemO1`1PH609065QH@D0HV9R1`1SHf<706ATI0@0oooo
0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`80Hf=S1@1RHV87065QH@L0H61P1@1O
Gel705iNGPT0GEeM2P1LG5`905]KF``0FUYJ4`1IFETd05QHF1<0FEUI301JFUX905]KF`X0G5aL2@1M
GEd705iNGPD0GemO1`1PH607065QH@D0HV9R0P1SHf<40?ooo`4000000@3oool002T0oooo00<00000
0?ooo`3oool00P3oool206=SH`D0HV9R1`1QHF47061PH0D0GemO1`1NGUh905eMG@X0G5aL2@1KFe/<
05YJFQ<0FEUI=01HF5PC05UIF@`0FUYJ2@1KFe/:05aLG0T0GEeM1`1NGUh505mOG`L0H61P1`1QHF45
069RHP80Hf=S103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo0P1QHF47061P
H0D0GemO1`1NGUh505eMG@L0G5aL1`1KFe/:05YJFPT0FEUI2@1HF5PA05MGEd80EUIF4@1GEeL905QH
F0T0FEUI2P1JFUX705]KF`L0G5aL1@1MGEd705iNGPD0GemO1`1PH602065QH@@0oooo0@0000010?oo
o`00:@3oool00`000000oooo0?ooo`020?ooo`80HF5Q1`1PH60505mOG`L0GUiN1@1MGEd705aLG0L0
Fe]K2P1JFUX905UIF@T0F5QH4@1GEeM205IFEQ40EeMG2@1HF5P905UIF@X0FUYJ1`1KFe/705aLG0D0
GEeM1`1NGUh505mOG`L0H61P0P1QHF440?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0
0P3oool2065QH@L0H61P1@1OGel705iNGPD0GEeM1`1LG5`705]KF`X0FUYJ2@1IFET905QHF140EeMG
@P1FEUHA05MGE`T0F5QH2@1IFET:05YJFPL0Fe]K1`1LG5`505eMG@L0GUiN1@1OGel7061PH080HF5Q
103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo1@1OGel405iNGPD0GEeM1`1L
G5`505]KF`L0FUYJ1`1IFET705QHF0X0EeMG2@1FEUH<05EEEA<0E5AD:P1CDe<C05ADE0`0EEEE2@1F
EUH:05MGE`L0F5QH1`1IFET705YJFPD0Fe]K1`1LG5`505eMG@@0GUiN1@1OGel40?ooo`4000000@3o
ool002T0oooo00<000000?ooo`3oool00P3oool505mOG`@0GUiN1@1MGEd705aLG0D0Fe]K1`1JFUX7
05UIF@L0F5QH2P1GEeL905IFEP`0EEEE4`1DE5@Z05=CDa<0E5AD301EEED905IFEPX0EeMG1`1HF5P7
05UIF@L0FUYJ1@1KFe/705aLG0D0GEeM101NGUh505mOG`@0oooo0@0000010?ooo`00:@3oool00`00
0000oooo0?ooo`020?ooo`D0GEeM101LG5`505]KF`L0FUYJ1@1IFET705QHF0D0EeMG1`1FEUH905EE
E@L0E5AD301CDe<>059BDSh0DE5A3P1BDU8<05=CD`L0E5AD2@1EEED705IFEPD0EeMG1`1HF5P505UI
F@L0FUYJ1@1KFe/405aLG0D0GEeM103oool100000040oooo000Y0?ooo`030000003oool0oooo0080
oooo1@1MGEd405aLG0D0Fe]K1`1JFUX505UIF@L0F5QH1@1GEeL705IFEPT0EEEE1`1DE5@<05=CD`h0
DU9B?P1ADE4>059BDP`0De=C1`1DE5@905EEE@L0EUIF1@1GEeL705QHF0D0FEUI1`1JFUX505]KF`@0
G5aL1@1MGEd40?ooo`4000000@3oool002T0oooo0P0000030?ooo`D0GEeM101LG5`505]KF`L0FUYJ
1@1IFET705QHF0D0EeMG1`1FEUH905EEE@L0E5AD301CDe<>059BDSh0DE5A3P1BDU8<05=CD`L0E5AD
2@1EEED705IFEPD0EeMG1`1HF5P505UIF@L0FUYJ1@1KFe/405aLG0D0GEeM0`3oool200000040oooo
000Y0?ooo`030000003oool0oooo0080oooo1@1KFe/405YJFPD0FEUI1@1HF5P705MGE`D0EUIF1`1E
EED705ADE0L0De=C1`1BDU89055AD@`0D51@4`1?CdlV04i>CQ<0Cdm?301@D509055AD@L0DU9B1`1C
De<705ADE0L0EEEE1@1FEUH705MGE`D0F5QH1@1IFET405YJFPD0Fe]K103oool100000040oooo000Y
0?ooo`030000003oool0oooo0080oooo1@1KFe/405YJFPD0FEUI1@1HF5P705MGE`D0EUIF1`1EEED7
05ADE0L0De=C1`1BDU89055AD@`0D51@4`1?CdlV04i>CQ<0Cdm?301@D509055AD@L0DU9B1`1CDe<7
05ADE0L0EEEE1@1FEUH705MGE`D0F5QH1@1IFET405YJFPD0Fe]K103oool100000040oooo000Y0?oo
o`030000003oool0oooo0080oooo0P1JFUX305UIF@@0F5QH1@1GEeL505IFEPL0EEEE1@1DE5@405=C
D`L0DU9B201ADE47051@D0T0Cdm?2P1>CTh>04e=CCP0C4a<3P1=CDd:04i>CPT0Cdm?1`1@D508055A
D@L0DU9B101CDe<505ADE0L0EEEE1@1FEUH505MGE`@0F5QH0`1IFET205YJFP@0oooo0@0000010?oo
o`00:@3oool00`000000oooo0?ooo`020?ooo`80FUYJ0`1IFET405QHF0D0EeMG1@1FEUH705EEE@D0
E5AD101CDe<7059BDPP0DE5A1`1@D50904m?C`X0CTi>3P1=CDdh04a<C0h0CDe=2P1>CTh904m?C`L0
D51@201ADE47059BDP@0De=C1@1DE5@705EEE@D0EUIF1@1GEeL405QHF0<0FEUI0P1JFUX40?ooo`40
00000@3oool002T0oooo00<000000?ooo`3oool00P3oool205QHF0D0EeMG0P1FEUH505EEE@D0E5AD
1@1CDe<7059BDP@0DE5A1@1@D50704m?C`L0CTi>1`1=CDd:04a<C0`0Bd];401:BTXV04U9BA00BTY:
301;Bd/:04a<C0L0CDe=1`1>CTh704m?C`D0D51@101ADE47059BDPD0De=C1@1DE5@505EEE@80EUIF
1@1GEeL205QHF0@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`80F5QH1@1G
EeL205IFEPD0EEEE1@1DE5@505=CD`L0DU9B101ADE45051@D0L0Cdm?1`1>CTh704e=C@X0C4a<301;
Bd/@04Y:BRH0BDU9401:BTX<04];B`X0C4a<1`1=CDd704i>CPL0Cdm?1@1@D504055AD@L0DU9B1@1C
De<505ADE0D0EEEE0P1FEUH505MGE`80F5QH103oool100000040oooo000Y0?ooo`030000003oool0
oooo0080oooo0P1HF5P505MGE`80EUIF1@1EEED505ADE0D0De=C1`1BDU84055AD@D0D51@1`1?Cdl7
04i>CPL0CDe=2P1<C4`<04];Ba00BTY:9P19BDT@04Y:BP`0Bd];2P1<C4`704e=C@L0CTi>1`1?Cdl5
051@D0@0DE5A1`1BDU8505=CD`D0E5AD1@1EEED205IFEPD0EeMG0P1HF5P40?ooo`4000000@3oool0
02T0oooo00<000000?ooo`3oool00P3oool205IFEPD0EEEE1@1DE5@205=CD`D0DU9B1@1ADE44051@
D0D0Cdm?1`1>CTh504e=C@L0C4a<1`1;Bd/904Y:BPX0BDU93018B4Ph04M7A``0B4Q82P19BDT904Y:
BPL0Bd];1`1<C4`504e=C@L0CTi>1@1?Cdl4051@D0D0DE5A1@1BDU8205=CD`D0E5AD1@1EEED205IF
EP@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`80EUIF1@1EEED505ADE080
De=C1@1BDU85055AD@@0D51@1@1?Cdl704i>CPD0CDe=1`1<C4`704];B`T0BTY:2P19BDT<04Q8B3P0
AdM73018B4P:04U9B@T0BTY:1`1;Bd/704a<C0D0CDe=1`1>CTh504m?C`@0D51@1@1ADE45059BDP80
De=C1@1DE5@505EEE@80EUIF103oool100000040oooo000F0?ooo`800000103oool2000000@0oooo
0P0000050?ooo`030000003oool0oooo0080oooo0P1DE5@505=CD`D0DU9B0P1ADE45051@D0D0Cdm?
101>CTh504e=C@D0C4a<1`1;Bd/504Y:BPL0BDU91`18B4P904M7A`X0ATI64015ADDV04A4A100ADE5
2P16ATH904M7A`L0B4Q81`19BDT504Y:BPL0Bd];1@1<C4`504e=C@@0CTi>1@1?Cdl5051@D080DE5A
1@1BDU8505=CD`80E5AD103oool100000040oooo000E0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`80E5AD1@1CDe<5059BDP80
DE5A1@1@D50504m?C`@0CTi>1@1=CDd504a<C0L0Bd];1@1:BTX704U9B@L0B4Q82@17AdL:04I6AQ00
ADE59P14A4@@04E5A@X0ATI62@17AdL704Q8B0L0BDU91@1:BTX704];B`D0C4a<1@1=CDd404i>CPD0
Cdm?1@1@D502055AD@D0DU9B1@1CDe<205ADE0@0oooo0@0000010?ooo`005@3oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo0080oooo0`0000020?ooo`80DU9B1@1ADE45051@D080
Cdm?1@1>CTh504e=C@@0C4a<1@1;Bd/504Y:BP@0BDU91@18B4P704M7A`L0ATI61`15ADD:04A4A0`0
@d=3>012@T8<04=3@`X0A4A41`15ADD704I6APL0AdM71@18B4P404U9B@D0BTY:1@1;Bd/404a<C0D0
CDe=1@1>CTh204m?C`D0D51@1@1ADE42059BDP<0oooo0P0000010?ooo`005@3oool010000000oooo
0?ooo`0000090?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`80DU9B1@1ADE45051@D080
Cdm?1@1>CTh504e=C@@0C4a<1@1;Bd/504Y:BP@0BDU91@18B4P704M7A`L0ATI61`15ADD:04A4A0`0
@d=3>012@T8<04=3@`X0A4A41`15ADD704I6APL0AdM71@18B4P404U9B@D0BTY:1@1;Bd/404a<C0D0
CDe=1@1>CTh204m?C`D0D51@1@1ADE42059BDP@0oooo0@0000010?ooo`005@3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool2059BDPD0
DE5A1@1@D50204m?C`D0CTi>1@1=CDd404a<C0D0Bd];1@1:BTX404U9B@D0B4Q81`17AdL704I6APL0
ADE52P14A4@<04=3@cP0@T923013@d<:04A4A0L0ADE51`16ATH704M7A`D0B4Q81019BDT504Y:BPD0
Bd];101<C4`504e=C@D0CTi>0P1?Cdl5051@D0D0DE5A0P1BDU840?ooo`4000000@3oool001H0oooo
0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`D0D51@0P1?Cdl504i>CP80CDe=
1@1<C4`504];B`80BTY:1@19BDT404Q8B0D0AdM71`16ATH504E5A@L0A4A41`13@d<70492@P`0@D51
3P10@40V03lo?`h0@4103011@D470492@PL0@d=31`14A4@504E5A@L0ATI61@17AdL404Q8B0D0BDU9
0P1:BTX504];B`D0C4a<0P1=CDd504i>CP80Cdm?1@1@D5040?ooo`4000000@3oool002T0oooo00<0
00000?ooo`3oool00P3oool5051@D080Cdm?1@1>CTh204e=C@D0C4a<1@1;Bd/204Y:BPD0BDU91018
B4P504M7A`L0ATI61@15ADD704A4A0L0@d=31`12@T8<0451@@h0@4109P0o?cl>0410@0`0@D511`12
@T8704=3@`L0A4A41@15ADD704I6APD0AdM71018B4P504U9B@80BTY:1@1;Bd/504a<C080CDe=1@1>
CTh204m?C`D0D51@103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo1@1>CTh2
04e=C@D0C4a<0P1;Bd/504Y:BP80BDU91@18B4P504M7A`@0ATI61@15ADD504A4A0D0@d=31`12@T87
0451@@L0@4101`0o?cl<03hn?QL0?Cdm2P0l?3`G03dm?@`0?Shn1`0o?cl70410@0L0@D511`12@T85
04=3@`D0A4A41@15ADD404I6APD0AdM71@18B4P204U9B@D0BTY:0P1;Bd/504a<C080CDe=1@1>CTh4
0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool504i>CP80CDe=1@1<C4`204];
B`D0BTY:0P19BDT504Q8B0D0AdM71016ATH504E5A@D0A4A41@13@d<70492@PL0@D511`10@40703lo
?``0?Shn5`0m?Cd:03`l?1L0?Cdm300n?Sh703lo?`L0@4101`11@D470492@PD0@d=31@14A4@504E5
A@@0ATI61@17AdL504Q8B080BDU91@1:BTX204];B`D0C4a<0P1=CDd504i>CP@0oooo0@0000010?oo
o`00:@3oool00`000000oooo0?ooo`020?ooo`D0C4a<0P1;Bd/504Y:BP80BDU91@18B4P204M7A`D0
ATI61@15ADD204A4A0D0@d=31012@T850451@@L0@4101@0o?cl703hn?PL0?Cdm2P0l?3`>03/k>bX0
>SXj3P0k>c/:03`l?0L0?Cdm1`0n?Sh503lo?`L0@4101@11@D440492@PD0@d=30P14A4@504E5A@D0
ATI60P17AdL504Q8B080BDU91@1:BTX204];B`D0C4a<103oool100000040oooo000Y0?ooo`030000
003oool0oooo0080oooo1@1<C4`204];B`D0BTY:0P19BDT504Q8B080AdM71@16ATH504E5A@80A4A4
1@13@d<40492@PD0@D511`10@40503lo?`L0?Shn1`0m?Cd:03`l?0h0>c/k:P0j>SX>03/k>`X0?3`l
1`0m?Cd703hn?PD0?clo1`10@4050451@@@0@T921@13@d<204A4A0D0ADE51@16ATH204M7A`D0B4Q8
0P19BDT504Y:BP80Bd];1@1<C4`40?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3o
ool504a<C080Bd];1@1:BTX204U9B@D0B4Q80P17AdL504I6APD0ADE50P14A4@504=3@`@0@T921@11
@D470410@0D0?clo1`0n?Sh703dm?@X0?3`l3P0k>c/Z03Xj>Ph0>c/k2P0l?3`703dm?@L0?Shn1@0o
?cl70410@0D0@D511012@T8504=3@`80A4A41@15ADD504I6AP80AdM71@18B4P204U9B@D0BTY:0P1;
Bd/504a<C0@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`D0BTY:0P19BDT5
04Q8B080AdM70`16ATH404E5A@D0A4A40P13@d<50492@PD0@D511010@40503lo?`D0?Shn1@0m?Cd7
03`l?0L0>c/k1`0j>SX<03Ti>A00>3Ph600g=cL@03Ph>0`0>CTi1`0j>SX703/k>`L0?3`l1@0m?Cd5
03hn?PD0?clo1010@4050451@@D0@T920P13@d<504A4A0@0ADE50`16ATH204M7A`D0B4Q80P19BDT5
04Y:BP@0oooo0@0000010?ooo`00:@3oool2000000<0oooo1@1:BTX204U9B@D0B4Q80P17AdL304I6
AP@0ADE51@14A4@204=3@`D0@T921@11@D440410@0D0?clo1@0n?Sh503dm?@L0?3`l1`0k>c/703Xj
>P`0>CTi400h>3PH03Lg=a00>3Ph300i>CT703Xj>PL0>c/k1`0l?3`503dm?@D0?Shn1@0o?cl40410
@0D0@D511@12@T8204=3@`D0A4A41015ADD304I6AP80AdM71@18B4P204U9B@D0BTY:0`3oool20000
0040oooo000Y0?ooo`030000003oool0oooo0080oooo0P19BDT304Q8B080AdM70P16ATH504E5A@<0
A4A41013@d<30492@P@0@D510`10@40403lo?`D0?Shn1@0m?Cd503`l?0@0>c/k1`0j>SX503Ti>@L0
>3Ph2P0g=cL;03Hf=S00=CDe2`0f=SH:03Lg=`L0>3Ph1@0i>CT703Xj>P@0>c/k1@0l?3`503dm?@D0
?Shn100o?cl30410@0@0@D510`12@T8404=3@`<0A4A41@15ADD204I6AP80AdM70`18B4P204U9B@@0
oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`80BDU90`18B4P204M7A`80ATI6
1@15ADD304A4A0@0@d=30`12@T840451@@<0@410100o?cl503hn?PD0?Cdm1@0l?3`403/k>`L0>SXj
1@0i>CT703Ph>0X0=cLg2`0f=SH`03De=@/0=SHf2P0g=cL703Ph>0D0>CTi1`0j>SX403/k>`D0?3`l
1@0m?Cd503hn?P@0?clo0`10@4040451@@<0@T921013@d<304A4A0D0ADE50P16ATH204M7A`<0B4Q8
0P19BDT40?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool204M7A`<0ATI60P15
ADD204A4A0D0@d=30`12@T820451@@D0@4100P0o?cl503hn?P@0?Cdm0`0l?3`403/k>`D0>SXj1@0i
>CT503Ph>0L0=cLg1`0f=SH703De=@T0=3@d3P0c<c<R038b<Ph0<c<c2@0d=3@703De=@L0=SHf1`0g
=cL503Ph>0D0>CTi1@0j>SX403/k>`<0?3`l100m?Cd503hn?P80?clo1@10@4020451@@<0@T921@13
@d<204A4A080ADE50`16ATH204M7A`@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`02
0?ooo`80AdM70`16ATH204E5A@80A4A41@13@d<30492@P80@D511@10@40203lo?`D0?Shn100m?Cd3
03`l?0@0>c/k1@0j>SX503Ti>@D0>3Ph1`0g=cL703Hf=PL0=CDe2@0d=3@>03<c<b80<S8b3P0c<c<9
03@d=0L0=CDe1`0f=SH703Lg=`D0>3Ph1@0i>CT503Xj>P@0>c/k0`0l?3`403dm?@D0?Shn0P0o?cl5
0410@080@D510`12@T8504=3@`80A4A40P15ADD304I6AP80AdM7103oool100000040oooo000Y0?oo
o`030000003oool0oooo0080oooo0P17AdL304I6AP80ADE50P14A4@504=3@`<0@T920P11@D450410
@080?clo1@0n?Sh403dm?@<0?3`l100k>c/503Xj>PD0>CTi1@0h>3P703Lg=`L0=SHf1`0e=CD903@d
=0h0<c<c8P0b<S8>03<c<`T0=3@d1`0e=CD703Hf=PL0=cLg1@0h>3P503Ti>@D0>SXj100k>c/303`l
?0@0?Cdm1@0n?Sh203lo?`D0@4100P11@D430492@PD0@d=30P14A4@204E5A@<0ATI60P17AdL40?oo
o`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool204E5A@<0A4A40P13@d<20492@PD0
@D510`10@40203lo?`D0?Shn0P0m?Cd503`l?080>c/k1@0j>SX403Ti>@<0>3Ph1@0g=cL403Hf=PL0
=CDe1@0d=3@703<c<`L0<S8b300a<C4C030`<0h0;bl_4`0`<30<034a<@L0<S8b1`0c<c<503@d=0L0
=CDe100f=SH503Lg=`<0>3Ph100i>CT503Xj>P80>c/k1@0l?3`203dm?@D0?Shn0P0o?cl30410@0D0
@D510P12@T8204=3@`<0A4A40P15ADD40?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool0
0P3oool204E5A@<0A4A40P13@d<20492@PD0@D510`10@40203lo?`D0?Shn0P0m?Cd503`l?080>c/k
1@0j>SX403Ti>@<0>3Ph1@0g=cL403Hf=PL0=CDe1@0d=3@703<c<`L0<S8b300a<C4C030`<0h0;bl_
4`0`<30<034a<@L0<S8b1`0c<c<503@d=0L0=CDe100f=SH503Lg=`<0>3Ph100i>CT503Xj>P80>c/k
1@0l?3`203dm?@D0?Shn0P0o?cl30410@0D0@D510P12@T8204=3@`<0A4A40P15ADD40?ooo`400000
0@3oool002T0oooo00<000000?ooo`3oool00P3oool204=3@`<0@T920P11@D420410@0<0?clo1@0n
?Sh203dm?@80?3`l1@0k>c/203Xj>PD0>CTi0P0h>3P503Lg=`D0=SHf0P0e=CD503@d=0L0<c<c1@0b
<S84034a<@P0<30`2@0_;bl<02h^;RX0;Bd]300^;Rh902l_;`P0<30`100a<C45038b<PL0<c<c1@0d
=3@203De=@D0=SHf1@0g=cL203Ph>0D0>CTi0P0j>SX503/k>`80?3`l0P0m?Cd503hn?P<0?clo0P10
@4020451@@<0@T920P13@d<40?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool2
04=3@`<0@T920P11@D420410@0<0?clo1@0n?Sh203dm?@80?3`l1@0k>c/203Xj>PD0>CTi0P0h>3P5
03Lg=`D0=SHf0P0e=CD503@d=0L0<c<c1@0b<S84034a<@P0<30`2@0_;bl<02h^;RX0;Bd]300^;Rh9
02l_;`P0<30`100a<C45038b<PL0<c<c1@0d=3@203De=@D0=SHf1@0g=cL203Ph>0D0>CTi0P0j>SX5
03/k>`80?3`l0P0m?Cd503hn?P<0?clo0P10@4020451@@<0@T920P13@d<40?ooo`4000000@3oool0
02T0oooo00<000000?ooo`3oool00P3oool20451@@<0@4100P0o?cl203hn?P<0?Cdm0P0l?3`503/k
>`80>SXj0`0i>CT403Ph>0<0=cLg100f=SH303De=@@0=3@d1@0c<c<5038b<PD0<C4a100`<30502l_
;`L0;Rh^1`0];Bd:02`/;0/0:b/[8P0Z:RX;02/[:`X0;2`/1`0];Bd702h^;PD0;bl_100`<305034a
<@D0<S8b1@0c<c<403@d=0<0=CDe100f=SH303Lg=`@0>3Ph0`0i>CT203Xj>PD0>c/k0P0l?3`303dm
?@80?Shn0P0o?cl30410@080@D51103oool100000040oooo000Y0?ooo`030000003oool0oooo0080
oooo0P11@D430410@080?clo0P0n?Sh303dm?@80?3`l1@0k>c/203Xj>P<0>CTi100h>3P303Lg=`@0
=SHf0`0e=CD403@d=0D0<c<c1@0b<S85034a<@@0<30`1@0_;bl702h^;PL0;Bd]2P0/;2`;02/[:b80
:RXZ2`0[:b/:02`/;0L0;Bd]1`0^;Rh502l_;`@0<30`1@0a<C45038b<PD0<c<c100d=3@303De=@@0
=SHf0`0g=cL403Ph>0<0>CTi0P0j>SX503/k>`80?3`l0`0m?Cd203hn?P80?clo0`10@4020451@@@0
oooo0@0000010?ooo`00:@3oool2000000<0oooo0P11@D430410@080?clo0P0n?Sh303dm?@80?3`l
1@0k>c/203Xj>P<0>CTi100h>3P303Lg=`@0=SHf0`0e=CD403@d=0D0<c<c1@0b<S85034a<@@0<30`
1@0_;bl702h^;PL0;Bd]2P0/;2`;02/[:b80:RXZ2`0[:b/:02`/;0L0;Bd]1`0^;Rh502l_;`@0<30`
1@0a<C45038b<PD0<c<c100d=3@303De=@@0=SHf0`0g=cL403Ph>0<0>CTi0P0j>SX503/k>`80?3`l
0`0m?Cd203hn?P80?clo0`10@4020451@@<0oooo0P0000010?ooo`00:@3oool00`000000oooo0?oo
o`020?ooo`80?clo0`0n?Sh203dm?@80?3`l0`0k>c/203Xj>P<0>CTi100h>3P303Lg=`80=SHf1@0e
=CD203@d=0D0<c<c0P0b<S85034a<@D0<30`100_;bl502h^;PD0;Bd]100/;2`802/[:`L0:RXZ2@0Y
:BTC02PX:0h09bLW4`0X:2P902TY:@L0:RXZ200[:b/402`/;0D0;Bd]1@0^;Rh402l_;`D0<30`1@0a
<C42038b<PD0<c<c0P0d=3@503De=@80=SHf0`0g=cL403Ph>0<0>CTi0P0j>SX303/k>`80?3`l0P0m
?Cd303hn?P80?clo103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo0P0o?cl3
03hn?P80?Cdm0P0l?3`303/k>`80>SXj0`0i>CT403Ph>0<0=cLg0P0f=SH503De=@80=3@d1@0c<c<2
038b<PD0<C4a1@0`<30402l_;`D0;Rh^1@0];Bd402`/;0P0:b/[1`0Z:RX902TY:A<0:2PX3P0W9bLC
02PX:0T0:BTY1`0Z:RX802/[:`@0;2`/1@0];Bd502h^;P@0;bl_1@0`<305034a<@80<S8b1@0c<c<2
03@d=0D0=CDe0P0f=SH303Lg=`@0>3Ph0`0i>CT203Xj>P<0>c/k0P0l?3`203dm?@<0?Shn0P0o?cl4
0?ooo`4000000@3oool002T0oooo00<000000?ooo`3oool00P3oool503`l?080>c/k0P0j>SX303Ti
>@80>3Ph0`0g=cL203Hf=PD0=CDe0P0d=3@203<c<`D0<S8b0P0a<C45030`<080;bl_1@0^;Rh502d]
;@80;2`/1@0[:b/702XZ:PD0:BTY1`0X:2P702LW9``09RHV:P0U9BD<02HV9PL09bLW1`0X:2P502TY
:@L0:RXZ1@0[:b/202`/;0D0;Bd]1@0^;Rh202l_;`D0<30`0P0a<C45038b<P80<c<c0P0d=3@503De
=@80=SHf0`0g=cL203Ph>0<0>CTi0P0j>SX203/k>`D0?3`l103oool100000040oooo000Y0?ooo`03
0000003oool0oooo0080oooo1@0l?3`203/k>`80>SXj0`0i>CT203Ph>0<0=cLg0P0f=SH503De=@80
=3@d0P0c<c<5038b<P80<C4a1@0`<30202l_;`D0;Rh^1@0];Bd202`/;0D0:b/[1`0Z:RX502TY:@L0
:2PX1`0W9bL<02HV9RX09BDU300V9RH702LW9`L0:2PX1@0Y:BT702XZ:PD0:b/[0P0/;2`502d];@D0
;Rh^0P0_;bl5030`<080<C4a1@0b<S8203<c<`80=3@d1@0e=CD203Hf=P<0=cLg0P0h>3P303Ti>@80
>SXj0P0k>c/503`l?0@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`80>SXj
0`0i>CT403Ph>0<0=cLg0P0f=SH303De=@80=3@d0P0c<c<3038b<P@0<C4a0`0`<30202l_;`D0;Rh^
0P0];Bd502`/;0D0:b/[0P0Z:RX502TY:@@0:2PX1`0W9bL502HV9PL09BDU2P0T92@;02<S8b808R8R
2`0S8b<:02@T90L09BDU1@0V9RH702LW9`@0:2PX1@0Y:BT202XZ:PD0:b/[1@0/;2`202d];@D0;Rh^
0P0_;bl3030`<0@0<C4a0`0b<S8203<c<`80=3@d0`0e=CD203Hf=P<0=cLg100h>3P303Ti>@80>SXj
103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo0P0j>SX303Ti>@@0>3Ph0`0g
=cL203Hf=P<0=CDe0P0d=3@203<c<`<0<S8b100a<C43030`<080;bl_1@0^;Rh202d];@D0;2`/1@0[
:b/202XZ:PD0:BTY100X:2P702LW9`D09RHV1`0U9BD:02@T90/08b<S8P0R8R8;02<S8`X092@T1`0U
9BD502HV9PL09bLW100X:2P502TY:@80:RXZ1@0[:b/502`/;080;Bd]1@0^;Rh202l_;`<0<30`100a
<C43038b<P80<c<c0P0d=3@303De=@80=SHf0`0g=cL403Ph>0<0>CTi0P0j>SX40?ooo`4000000@3o
ool002T0oooo00<000000?ooo`3oool00P3oool203Xj>P<0>CTi100h>3P303Lg=`80=SHf0`0e=CD2
03@d=080<c<c0`0b<S84034a<@<0<30`0P0_;bl502h^;P80;Bd]1@0/;2`502/[:`80:RXZ1@0Y:BT4
02PX:0L09bLW1@0V9RH702DU9@X092@T2`0S8b<R028R8P/08b<S2P0T92@702DU9@D09RHV1`0W9bL4
02PX:0D0:BTY0P0Z:RX502/[:`D0;2`/0P0];Bd502h^;P80;bl_0`0`<304034a<@<0<S8b0P0c<c<2
03@d=0<0=CDe0P0f=SH303Lg=`@0>3Ph0`0i>CT203Xj>P@0oooo0@0000010?ooo`00:@3oool00`00
0000oooo0?ooo`020?ooo`80>3Ph0`0g=cL203Hf=P80=CDe0`0d=3@503<c<`80<S8b0P0a<C43030`
<080;bl_1@0^;Rh202d];@80;2`/1@0[:b/202XZ:PD0:BTY0`0X:2P402LW9`D09RHV1@0U9BD402@T
90P08b<S1`0R8R89024Q8@h0820P600O7al>020P80T08B4Q1`0R8R8802<S8`@092@T1@0U9BD502HV
9P@09bLW0`0X:2P502TY:@80:RXZ1@0[:b/202`/;080;Bd]1@0^;Rh202l_;`<0<30`0P0a<C42038b
<PD0<c<c0`0d=3@203De=@80=SHf0`0g=cL203Ph>0@0oooo0@0000010?ooo`00:@3oool00`000000
oooo0?ooo`020?ooo`80>3Ph0`0g=cL203Hf=P80=CDe0`0d=3@503<c<`80<S8b0P0a<C43030`<080
;bl_1@0^;Rh202d];@80;2`/1@0[:b/202XZ:PD0:BTY0`0X:2P402LW9`D09RHV1@0U9BD402@T90P0
8b<S1`0R8R89024Q8@h0820P600O7al>020P80T08B4Q1`0R8R8802<S8`@092@T1@0U9BD502HV9P@0
9bLW0`0X:2P502TY:@80:RXZ1@0[:b/202`/;080;Bd]1@0^;Rh202l_;`<0<30`0P0a<C42038b<PD0
<c<c0`0d=3@203De=@80=SHf0`0g=cL203Ph>0@0oooo0@0000010?ooo`00:@3oool00`000000oooo
0?ooo`020?ooo`80=SHf0`0e=CD203@d=080<c<c0`0b<S82034a<@<0<30`100_;bl302h^;P80;Bd]
0P0/;2`302/[:`@0:RXZ0`0Y:BT202PX:0D09bLW1@0V9RH202DU9@D092@T100S8b<5028R8PD08B4Q
1`0P820701lO7`T07QhN4`0M7Ad:01`L71<07AdM2@0N7Qh701lO7`L0820P1@0Q8B45028R8P@08b<S
1@0T92@202DU9@D09RHV1@0W9bL202PX:0<0:BTY100Z:RX302/[:`80;2`/0P0];Bd302h^;P@0;bl_
0`0`<302034a<@<0<S8b0P0c<c<203@d=0<0=CDe0P0f=SH40?ooo`4000000@3oool002T0oooo00<0
00000?ooo`3oool00P3oool203Hf=P<0=CDe0P0d=3@203<c<`<0<S8b0P0a<C43030`<0@0;bl_0`0^
;Rh202d];@80;2`/0`0[:b/402XZ:P<0:BTY0P0X:2P502LW9`D09RHV0P0U9BD502@T90@08b<S1@0R
8R85024Q8@L0820P1`0O7al901hN7Q<07AdM2P0L71`C01dM7@T07QhN1`0O7al7020P80D08B4Q1@0R
8R8402<S8`D092@T0P0U9BD502HV9PD09bLW0P0X:2P302TY:@@0:RXZ0`0[:b/202`/;080;Bd]0`0^
;Rh402l_;`<0<30`0P0a<C43038b<P80<c<c0P0d=3@303De=@80=SHf103oool100000040oooo000Y
0?ooo`8000000`3oool203Hf=P<0=CDe0P0d=3@203<c<`<0<S8b0P0a<C43030`<0@0;bl_0`0^;Rh2
02d];@80;2`/0`0[:b/402XZ:P<0:BTY0P0X:2P502LW9`D09RHV0P0U9BD502@T90@08b<S1@0R8R85
024Q8@L0820P1`0O7al901hN7Q<07AdM2P0L71`C01dM7@T07QhN1`0O7al7020P80D08B4Q1@0R8R84
02<S8`D092@T0P0U9BD502HV9PD09bLW0P0X:2P302TY:@@0:RXZ0`0[:b/202`/;080;Bd]0`0^;Rh4
02l_;`<0<30`0P0a<C43038b<P80<c<c0P0d=3@303De=@80=SHf0`3oool200000040oooo000Y0?oo
o`030000003oool0oooo0080oooo0P0d=3@303<c<`80<S8b0P0a<C43030`<080;bl_0`0^;Rh202d]
;@80;2`/0`0[:b/402XZ:P<0:BTY0P0X:2P202LW9`D09RHV0P0U9BD502@T90<08b<S100R8R85024Q
8@D0820P100O7al501hN7PL07AdM1`0L71`:01/K6bX06QXJ2P0K6a/701`L70L07AdM1@0N7Qh401lO
7`D0820P1@0Q8B44028R8P<08b<S1@0T92@202DU9@D09RHV0P0W9bL202PX:0<0:BTY100Z:RX302/[
:`80;2`/0P0];Bd302h^;P80;bl_0`0`<302034a<@80<S8b0`0c<c<203@d=0@0oooo0@0000010?oo
o`00:@3oool00`000000oooo0?ooo`020?ooo`80=3@d0`0c<c<2038b<P80<C4a0`0`<30202l_;`<0
;Rh^0P0];Bd202`/;0<0:b/[100Z:RX302TY:@80:2PX0P0W9bL502HV9P809BDU1@0T92@302<S8`@0
8R8R1@0Q8B45020P80@07alO1@0N7Qh701dM7@L071`L2P0K6a/Z01XJ6PX06a/K1`0L71`701dM7@D0
7QhN100O7al5020P80D08B4Q100R8R8302<S8`D092@T0P0U9BD502HV9P809bLW0P0X:2P302TY:@@0
:RXZ0`0[:b/202`/;080;Bd]0`0^;Rh202l_;`<0<30`0P0a<C42038b<P<0<c<c0P0d=3@40?ooo`40
00000@3oool002T0oooo00<000000?ooo`3oool00P3oool2038b<P<0<C4a0P0`<30202l_;`<0;Rh^
0P0];Bd302`/;080:b/[0P0Z:RX302TY:@80:2PX0P0W9bL302HV9P@09BDU0`0T92@202<S8`D08R8R
0P0Q8B45020P80D07alO0P0N7Qh501dM7@@071`L200K6a/401XJ6PX06ATI2@0H61PV01LG5`T061PH
2P0I6AT401XJ6PP06a/K100L71`501dM7@807QhN1@0O7al5020P80808B4Q1@0R8R8202<S8`<092@T
100U9BD302HV9P809bLW0P0X:2P302TY:@80:RXZ0P0[:b/302`/;080;Bd]0`0^;Rh202l_;`80<30`
0`0a<C42038b<P@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`80<S8b0`0a
<C42030`<080;bl_0`0^;Rh202d];@<0;2`/0P0[:b/202XZ:P<0:BTY0P0X:2P202LW9`<09RHV100U
9BD302@T90808b<S1@0R8R82024Q8@D0820P1@0O7al201hN7PD07AdM100L71`801/K6`@06QXJ2P0I
6AT901PH62H05aLG2@0H61P:01TI6@@06QXJ200K6a/401`L70D07AdM0P0N7Qh501lO7`D0820P0P0Q
8B45028R8P808b<S0`0T92@402DU9@<09RHV0P0W9bL202PX:0<0:BTY0P0Z:RX202/[:`<0;2`/0P0]
;Bd302h^;P80;bl_0P0`<303034a<@80<S8b103oool100000040oooo000Y0?ooo`030000003oool0
oooo0080oooo0P0`<30302l_;`80;Rh^0P0/;2`302/[:`80:RXZ0`0Y:BT202PX:0809bLW1@0V9RH2
02DU9@<092@T0P0S8b<2028R8PD08B4Q0P0P820301lO7`D07QhN0P0M7Ad501`L70@06a/K1@0J6QX5
01TI6@D061PH1`0G5aL701HF5P/05ADE8P0D51@;01DE5@L05QHF1`0G5aL501PH60D06ATI1@0J6QX4
01/K6`D071`L0P0M7Ad501hN7P<07alO0P0P8205024Q8@808R8R0P0S8b<302@T90809BDU1@0V9RH2
02LW9`80:2PX0`0Y:BT202XZ:P<0:b/[0P0/;2`202h^;P<0;bl_0P0`<3040?ooo`4000000@3oool0
02T0oooo00<000000?ooo`3oool00P3oool2030`<0<0;bl_0P0^;Rh202`/;0<0:b/[0P0Z:RX302TY
:@80:2PX0P0W9bL502HV9P809BDU0`0T92@202<S8`808R8R1@0Q8B42020P80<07alO1@0N7Qh201dM
7@D071`L100K6a/501XJ6PD06ATI1@0H61P701LG5`L05QHF2`0E5ADR01@D50/05ADE1`0F5QH701LG
5`D061PH1@0I6AT501XJ6P@06a/K1@0L71`201dM7@D07QhN0`0O7al2020P80D08B4Q0P0R8R8202<S
8`<092@T0P0U9BD502HV9P809bLW0P0X:2P302TY:@80:RXZ0`0[:b/202`/;080;Rh^0`0_;bl2030`
<0@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`80<30`0`0_;bl202h^;P80
;2`/0`0[:b/202XZ:P<0:BTY0P0X:2P202LW9`D09RHV0P0U9BD302@T90808b<S0P0R8R85024Q8@80
820P0`0O7al501hN7P807AdM1@0L71`401/K6`D06QXJ1@0I6AT501PH60L05aLG1`0F5QH;01DE5B80
51@D2`0E5AD701HF5PL05aLG1@0H61P501TI6@D06QXJ100K6a/501`L70807AdM1@0N7Qh301lO7`80
820P1@0Q8B42028R8P808b<S0`0T92@202DU9@D09RHV0P0W9bL202PX:0<0:BTY0P0Z:RX302/[:`80
;2`/0P0^;Rh302l_;`80<30`103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo
0P0^;Rh302`/;080:b/[0P0Z:RX302TY:@80:2PX0`0W9bL202HV9P809BDU0`0T92@202<S8`808R8R
0`0Q8B44020P80<07alO0P0N7Qh501dM7@8071`L0`0K6a/401XJ6PD06ATI0P0H61P501LG5`D05QHF
1`0E5AD701@D50L04a<C300B4Q8L014A4@`04Q8B1`0C4a<701@D50L05ADE1@0F5QH501LG5`8061PH
1@0I6AT401XJ6P<06a/K0P0L71`501dM7@807QhN0`0O7al4020P80<08B4Q0P0R8R8202<S8`<092@T
0P0U9BD202HV9P<09bLW0P0X:2P302TY:@80:RXZ0P0[:b/302`/;080;Rh^103oool100000040oooo
000Y0?ooo`030000003oool0oooo0080oooo0P0^;Rh302`/;080:b/[0P0Z:RX302TY:@80:2PX0`0W
9bL202HV9P809BDU0`0T92@202<S8`808R8R0`0Q8B44020P80<07alO0P0N7Qh501dM7@8071`L0`0K
6a/401XJ6PD06ATI0P0H61P501LG5`D05QHF1`0E5AD701@D50L04a<C300B4Q8L014A4@`04Q8B1`0C
4a<701@D50L05ADE1@0F5QH501LG5`8061PH1@0I6AT401XJ6P<06a/K0P0L71`501dM7@807QhN0`0O
7al4020P80<08B4Q0P0R8R8202<S8`<092@T0P0U9BD202HV9P<09bLW0P0X:2P302TY:@80:RXZ0P0[
:b/302`/;080;Rh^103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo0P0[:b/3
02XZ:P80:BTY0P0X:2P302LW9`809RHV0`0U9BD202@T90808b<S0`0R8R82024Q8@80820P0`0O7al2
01hN7P807AdM0`0L71`401/K6`<06QXJ0P0I6AT501PH60805aLG1@0F5QH501DE5@@051@D1@0C4a<5
018B4PL04A4A2@0@410<00l?3aP03Ph>300?3`l9010@40L04A4A1@0B4Q8501<C4`@051@D1@0E5AD5
01HF5P805aLG1@0H61P201TI6@<06QXJ100K6a/301`L70807AdM0P0N7Qh301lO7`80820P0P0Q8B43
028R8P808b<S0P0T92@302DU9@809RHV0`0W9bL202PX:080:BTY0`0Z:RX202/[:`@0oooo0@000001
0?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`80:b/[0`0Z:RX202TY:@80:2PX0`0W9bL202HV
9P<09BDU0P0T92@202<S8`<08R8R0P0Q8B42020P80<07alO0P0N7Qh201dM7@<071`L100K6a/301XJ
6P806ATI1@0H61P201LG5`D05QHF1@0E5AD401@D50D04a<C1@0B4Q87014A4@T0410@300?3`lH00h>
3P`03`l?2@0@4107014A4@D04Q8B1@0C4a<401@D50D05ADE1@0F5QH201LG5`D061PH0P0I6AT301XJ
6P@06a/K0`0L71`201dM7@807QhN0`0O7al2020P80808B4Q0`0R8R8202<S8`8092@T0`0U9BD202HV
9P<09bLW0P0X:2P202TY:@<0:RXZ0P0[:b/40?ooo`4000000@3oool002T0oooo0P0000030?ooo`80
:BTY0`0X:2P202LW9`809RHV0`0T92@202<S8`<08R8R0P0Q8B42020P80<07alO0P0N7Qh201dM7@<0
71`L100K6a/301XJ6P806ATI0P0H61P501LG5`<05QHF0P0E5AD501@D50@04a<C0`0B4Q84014A4@D0
410@1`0?3`l700h>3PL03@d=4@0<30`>00/;2a4030`<1`0=3@d700h>3PL03`l?1@0@4104014A4@<0
4Q8B100C4a<501@D50805ADE0`0F5QH501LG5`8061PH0P0I6AT301XJ6P@06a/K0`0L71`201dM7@80
7QhN0`0O7al2020P80808B4Q0`0R8R8202<S8`<092@T0P0V9RH202LW9`<0:2PX0P0Y:BT30?ooo`80
00000@3oool002T0oooo00<000000?ooo`3oool00P3oool202TY:@<0:2PX0P0W9bL202HV9P<092@T
0P0S8b<3028R8P808B4Q0P0P820301lO7`807QhN0P0M7Ad301`L70@06a/K0`0J6QX201TI6@8061PH
1@0G5aL301HF5P805ADE1@0D51@401<C4`<04Q8B100A4A45010@40L03`l?1`0>3Ph700d=3A4030`<
3P0;2`/A00`<30L03@d=1`0>3Ph700l?3`D0410@100A4A43018B4P@04a<C1@0D51@201DE5@<05QHF
1@0G5aL201PH60806ATI0`0J6QX401/K6`<071`L0P0M7Ad201hN7P<07alO0P0P8202024Q8@<08R8R
0P0S8b<302@T90809RHV0P0W9bL302PX:080:BTY103oool100000040oooo000Y0?ooo`030000003o
ool0oooo0080oooo0P0Y:BT302PX:0809bLW0P0V9RH302@T90808b<S0`0R8R82024Q8@80820P0`0O
7al201hN7P807AdM0`0L71`401/K6`<06QXJ0P0I6AT201PH60D05aLG0`0F5QH201DE5@D051@D100C
4a<3018B4P@04A4A1@0@410700l?3`L03Ph>1`0=3@dA00`<30h02`/;4@0<30`700d=3@L03Ph>1`0?
3`l5010@40@04A4A0`0B4Q8401<C4`D051@D0P0E5AD301HF5PD05aLG0P0H61P201TI6@<06QXJ100K
6a/301`L70807AdM0P0N7Qh301lO7`80820P0P0Q8B43028R8P808b<S0`0T92@202HV9P809bLW0`0X
:2P202TY:@@0oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`809bLW0`0V9RH2
02@T90808b<S0`0R8R82024Q8@<0820P0P0O7al201hN7P<07AdM0P0L71`201/K6`<06QXJ0P0I6AT2
01PH60<05aLG0P0F5QH501DE5@8051@D0`0C4a<4018B4P<04A4A100@410500l?3`D03Ph>1@0=3@d4
00`<30L02`/;2P0:2PX@00T92@X020P840092@T:00X:2PL02`/;100<30`500d=3@D03Ph>1@0?3`l4
010@40<04A4A100B4Q8301<C4`8051@D1@0E5AD201HF5P<05aLG0P0H61P201TI6@<06QXJ0P0K6a/2
01`L70<07AdM0P0N7Qh201lO7`<0820P0P0Q8B43028R8P808b<S0P0T92@302HV9P809bLW103oool1
00000040oooo000Y0?ooo`030000003oool0oooo0080oooo0P0W9bL302HV9P8092@T0P0S8b<3028R
8P808B4Q0`0P820201lO7`807QhN0`0M7Ad201`L70806a/K0`0J6QX201TI6@8061PH0`0G5aL201HF
5PD05ADE0P0D51@301<C4`@04Q8B0`0A4A44010@40D03`l?1@0>3Ph500d=3@@030`<1`0;2`/:00X:
2Q002@T92P0820P@00T92@X02PX:1`0;2`/400`<30D03@d=1@0>3Ph500l?3`@0410@0`0A4A44018B
4P<04a<C0P0D51@501DE5@805QHF0`0G5aL201PH60806ATI0`0J6QX201/K6`8071`L0`0M7Ad201hN
7P807alO0`0P8202024Q8@<08R8R0P0S8b<202@T90<09RHV0P0W9bL40?ooo`4000000@3oool002T0
oooo00<000000?ooo`3oool00P3oool202@T90<08b<S0P0R8R82024Q8@<0820P0P0N7Qh301dM7@80
71`L0P0K6a/301XJ6P806ATI0P0H61P301LG5`805QHF0P0E5AD501@D50804a<C0`0B4Q82014A4@D0
410@0P0?3`l500h>3P803@d=1@0<30`500/;2`D02PX:10092@T700P820X01`L74`061PH400D51A<0
1PH62P071`L700P820@02@T91@0:2PX500/;2`D030`<0P0=3@d500h>3P803`l?1@0@4102014A4@<0
4Q8B0P0C4a<501@D50805ADE0P0F5QH301LG5`8061PH0P0I6AT301XJ6P806a/K0P0L71`301dM7@80
7QhN0`0P8202024Q8@808R8R0`0S8b<202@T90@0oooo0@0000010?ooo`00:@3oool00`000000oooo
0?ooo`020?ooo`8092@T0`0S8b<2028R8P808B4Q0`0P820201hN7P<07AdM0P0L71`201/K6`<06QXJ
0P0I6AT201PH60<05aLG0P0F5QH201DE5@D051@D0P0C4a<3018B4P804A4A1@0@410200l?3`D03Ph>
0P0=3@d500`<30D02`/;1@0:2PX400T92@L020P82P071`LC00H61P@01@D54`061PH:00L71`L020P8
10092@T500X:2PD02`/;1@0<30`200d=3@D03Ph>0P0?3`l5010@40804A4A0`0B4Q8201<C4`D051@D
0P0E5AD201HF5P<05aLG0P0H61P201TI6@<06QXJ0P0K6a/201`L70<07AdM0P0N7Qh3020P80808B4Q
0P0R8R8302<S8`8092@T103oool100000040oooo000Y0?ooo`030000003oool0oooo0080oooo0P0R
8R83024Q8@80820P0P0N7Qh301dM7@8071`L0`0K6a/201XJ6P806ATI0`0H61P201LG5`D05ADE0P0D
51@201<C4`<04Q8B0P0A4A42010@40<03`l?1@0>3Ph200d=3@8030`<1@0;2`/500X:2P802@T91@08
20P500L71`L01PH610051@D:00@412X00`<32P0410@400D51@L01PH61@071`L500P820802@T91@0:
2PX500/;2`8030`<0P0=3@d500h>3P<03`l?0P0@4102014A4@<04Q8B0P0C4a<201@D50D05ADE0P0G
5aL301PH60806ATI0P0J6QX301/K6`8071`L0`0M7Ad201hN7P80820P0`0Q8B42028R8P@0oooo0@00
00010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`808R8R0`0Q8B42020P80807QhN0`0M7Ad2
01`L70<06a/K0P0J6QX201TI6@<061PH0P0G5aL501DE5@8051@D0P0C4a<3018B4P804A4A0P0@4103
00l?3`D03Ph>0P0=3@d200`<30D02`/;1@0:2PX200T92@D020P81@071`L700H61P@01@D52P0410@Z
00<30`X010@410051@D700H61PD01`L71@0820P200T92@D02PX:1@0;2`/200`<30803@d=1@0>3Ph3
00l?3`80410@0P0A4A43018B4P804a<C0P0D51@501DE5@805aLG0`0H61P201TI6@806QXJ0`0K6a/2
01`L70<07AdM0P0N7Qh2020P80<08B4Q0P0R8R840?ooo`4000000@3oool00240oooo1@0000030?oo
o`030000003oool0oooo0080oooo0P0R8R83024Q8@80820P0P0N7Qh301dM7@8071`L0`0K6a/201XJ
6P806ATI0`0H61P201LG5`D05ADE0P0D51@201<C4`<04Q8B0P0A4A42010@40<03`l?1@0>3Ph200d=
3@8030`<1@0;2`/500X:2P802@T91@0820P500L71`L01PH610051@D:00@412X00`<32P0410@400D5
1@L01PH61@071`L500P820802@T91@0:2PX500/;2`8030`<0P0=3@d500h>3P<03`l?0P0@4102014A
4@<04Q8B0P0C4a<201@D50D05ADE0P0G5aL301PH60806ATI0P0J6QX301/K6`8071`L0`0M7Ad201hN
7P80820P0`0Q8B42028R8P@0oooo0@0000010?ooo`008`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo0P0P820301hN7P807AdM0P0L71`301/K6`806QXJ0`0H61P201LG5`80
5QHF0`0E5AD201@D50804a<C0`0B4Q82014A4@80410@0`0?3`l200h>3P803@d=1@0<30`300/;2`80
2PX:1@092@T200P820D01`L70P061PH500D51@D010@41`030`<700820PL00@41:P00000700410@L0
0P821`030`<500@410D01@D50P061PH500L71`8020P81@092@T200X:2P<02`/;1@0<30`200d=3@80
3Ph>0`0?3`l2010@40804A4A0`0B4Q8201<C4`8051@D0`0E5AD201HF5P805aLG0`0H61P201XJ6P<0
6a/K0P0L71`201dM7@<07QhN0P0P82040?ooo`4000000@3oool002<0oooo00<000000?ooo`3oool0
0`3oool300000080oooo0P0P820301hN7P807AdM0P0L71`301/K6`806QXJ0`0H61P201LG5`805QHF
0`0E5AD201@D50804a<C0`0B4Q82014A4@80410@0`0?3`l200h>3P803@d=1@0<30`300/;2`802PX:
1@092@T200P820D01`L70P061PH500D51@D010@41`030`<700820PL00@41:P00000700410@L00P82
1`030`<500@410D01@D50P061PH500L71`8020P81@092@T200X:2P<02`/;1@0<30`200d=3@803Ph>
0`0?3`l2010@40804A4A0`0B4Q8201<C4`8051@D0`0E5AD201HF5P805aLG0`0H61P201XJ6P<06a/K
0P0L71`201dM7@<07QhN0P0P82030?ooo`8000000@3oool002<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`3b0?ooo`4000000@3oool002<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`3b0?ooo`4000000@3oool00280oooo0P0000050?ooo`030000003oool0oooo
0?80oooo0@0000010?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000040oooo000Y0?ooooH0
00000@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.39461, -1.32499, 0.0084867, \
0.0084867}}]
}, Open  ]],

Cell[BoxData[
    \(\(\( (*\ \(\(http\)\(:\)\) // \(\(\(www . efunda . com/formulae\)/
              solid_mechanics\)/mat_mechanics\)/
          strain . 
            cfm\ *) \)\(\[IndentingNewLine]\)\(\[Gamma]\_yz \[Congruent] \
\[PartialD]w\/\[PartialD]y + \[PartialD]v\/\[PartialD]z, \[Gamma]\_xz \
\[Congruent] \[PartialD]u\/\[PartialD]z + \[PartialD]w\/\[PartialD]x, \
\[Gamma]\_xy \[Congruent] \[PartialD]v\/\[PartialD]x + \[PartialD]u\/\
\[PartialD]y\)\)\)], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x = \(y = 
        0\); \((\(1\/2\) \((\((x\/\(a/2\))\)\^2 + \((y\/\(b/2\))\)\^2)\))\)\^\
\(1/2\)\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[g \((1 - g)\), {g, 0, 1}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 2.35442 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .13244 -24 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -24 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -24 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.05)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.1)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.15)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.2)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(0.25)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03826 m
.02756 .03826 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .08535 m
.02756 .08535 L
s
.02381 .10889 m
.02756 .10889 L
s
.02381 .15598 m
.02756 .15598 L
s
.02381 .17952 m
.02756 .17952 L
s
.02381 .20307 m
.02756 .20307 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .2737 m
.02756 .2737 L
s
.02381 .29725 m
.02756 .29725 L
s
.02381 .32079 m
.02756 .32079 L
s
.02381 .34433 m
.02756 .34433 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .41497 m
.02756 .41497 L
s
.02381 .43851 m
.02756 .43851 L
s
.02381 .46205 m
.02756 .46205 L
s
.02381 .50914 m
.02756 .50914 L
s
.02381 .53269 m
.02756 .53269 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57978 m
.02756 .57978 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .10635 L
.10458 .19746 L
.14415 .27463 L
.18221 .34117 L
.22272 .40374 L
.26171 .45593 L
.30316 .50274 L
.34309 .53941 L
.3815 .56687 L
.40095 .57785 L
.42237 .58767 L
.44268 .59479 L
.45178 .59728 L
.46172 .59952 L
.4671 .60051 L
.4721 .6013 L
.47727 .60198 L
.48196 .60248 L
.48658 .60285 L
.4887 .60299 L
.49093 .60311 L
.49332 .6032 L
.49438 .60324 L
.49552 .60327 L
.49675 .60329 L
.49789 .60331 L
.49859 .60331 L
.49925 .60332 L
.50049 .60332 L
.50163 .60331 L
.50286 .6033 L
.50401 .60328 L
.50508 .60325 L
.50754 .60317 L
.51014 .60305 L
.51268 .6029 L
.51504 .60273 L
.5204 .60224 L
.5293 .60109 L
.53882 .59941 L
.54906 .59707 L
.56016 .59392 L
.58032 .58658 L
.60019 .57726 L
.62123 .56517 L
.65912 .5376 L
.69946 .50005 L
.73829 .45593 L
.77956 .40045 L
Mistroke
.81932 .33864 L
.85757 .27144 L
.89827 .19159 L
.93745 .1066 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00AP3oool2000000@0oooo0P0000030?ooo`@00000903oool2000000@0
oooo0P0000050?ooo`<000008`3oool2000000@0oooo0P0000030?ooo`<00000903oool2000000@0
oooo0P0000040?ooo`800000:P3oool5000000D0oooo00150?ooo`040000003oool0oooo000000P0
oooo00<000000?ooo`3oool0903oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo
0240oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000R0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool00`000000oooo0?ooo`050?ooo`00
A@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo02<0oooo00@000000?ooo`3o
ool00000203oool500000280oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
000R0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000:`3oool00`000000
oooo0?ooo`050?ooo`00A@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0280
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000S0?ooo`040000003oool0
oooo000000P0oooo0`00000S0?ooo`040000003oool0oooo000000T0oooo0P00000/0?ooo`030000
003oool0oooo00D0oooo00150?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00008`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0000002<0oooo00@000000?oo
o`3oool000002@3oool00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool00000:`3oool00`000000oooo0?ooo`050?ooo`00AP3oool2000000X0oooo0P00
000U0?ooo`8000002`3oool2000002@0oooo0P00000:0?ooo`<000008`3oool2000000X0oooo0P00
000[0?ooo`8000001`3oool00?l0oooo8@3oool00?l0oooo8@3oool001/0oooo00<000000?ooo`3o
ool0o`3oool30?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003o
ool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00503ooooo0000
00d00000000K0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`050?ooo`006`3oool200000?X0oooo00<000000?ooo`3oool01P3oool001/0oooo0P00
003j0?ooo`030000003oool0oooo00H0oooo000K0?ooo`030000003oool000000?P0oooo00<00000
0?ooo`3oool01`3oool001/0oooo00<000000?ooo`000000n03oool00`000000oooo0?ooo`070?oo
o`006`3oool300000?L0oooo00<000000?ooo`3oool0203oool001/0oooo00@000000?ooo`3oool0
0000mP3oool00`000000oooo0?ooo`080?ooo`006`3oool010000000oooo0?ooo`00003f0?ooo`03
0000003oool0oooo00P0oooo000K0?ooo`050000003oool0oooo0?ooo`000000m03oool00`000000
oooo0?ooo`090?ooo`006`3oool01@000000oooo0?ooo`3oool000000?@0oooo00<000000?ooo`3o
ool02@3oool001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3`0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`8000000`3oool00`000000oooo0?ooo`3`0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0l03oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0>h0oooo00<000000?ooo`3oool02`3oool001/0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`3^0?ooo`030000003oool0oooo00/0oooo000K0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0k03oool00`000000oooo0?ooo`0<0?ooo`006`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0>`0oooo00<000000?ooo`3oool0303oool001/0oooo0P000005
0?ooo`030000003oool0oooo0>/0oooo00<000000?ooo`3oool03@3oool001/0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`3Z0?ooo`030000003oool0oooo00d0oooo000K0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0jP3oool00`000000oooo0?ooo`0=0?ooo`00
6`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0>P0oooo00<000000?ooo`3oool0
3P3oool001/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3X0?ooo`030000003o
ool0oooo00h0oooo000K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0iP3oool0
0`000000oooo0?ooo`0?0?ooo`006`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0>H0oooo00<000000?ooo`3oool03`3oool001/0oooo0P0000080?ooo`030000003oool0oooo0>H0
oooo00<000000?ooo`3oool03`3oool001/0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`3T0?ooo`030000003oool0oooo0100oooo000K0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0i03oool00`000000oooo0?ooo`0@0?ooo`006`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0>80oooo00<000000?ooo`3oool04@3oool00080oooo0P0000040?oo
o`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0hP3oool00`000000oooo0?ooo`0A0?ooo`0000D0oooo0000003oool0oooo000000080?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool04P3oool000050?ooo`000000
oooo0?ooo`000000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo
0P00000;0?ooo`030000003oool0oooo0>00oooo00<000000?ooo`3oool04P3oool000050?ooo`00
0000oooo0?ooo`000000203oool010000000oooo0?ooo`0000030?ooo`8000001@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0=h0oooo00<000000?ooo`3oool04`3oool000050?oo
o`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3N0?ooo`030000003oool0oooo
01<0oooo00020?ooo`8000002P3oool2000000@0oooo0`0000040?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0g03oool00`000000oooo0?ooo`0D0?ooo`006`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0=`0oooo00<000000?ooo`3oool0503oool001/0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`3K0?ooo`030000003oool0oooo01D0oooo000K
0?ooo`8000003P3oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo01D0oooo000K0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`0F0?oo
o`006`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3o
ool05P3oool001/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3G0?ooo`030000
003oool0oooo01L0oooo000K0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0eP3o
ool00`000000oooo0?ooo`0G0?ooo`006`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0=D0oooo00<000000?ooo`3oool0603oool001/0oooo0P00000A0?ooo`030000003oool0oooo
0=@0oooo00<000000?ooo`3oool0603oool001/0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`3C0?ooo`030000003oool0oooo01T0oooo000K0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0I0?ooo`006`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool06P3oool001/0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo01X0oooo000K0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`0J0?oo
o`006`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3o
ool06`3oool001/0oooo0P00000D0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0
6`3oool001/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo01`0oooo000K0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0c03oool0
0`000000oooo0?ooo`0L0?ooo`006`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0<X0oooo00<000000?ooo`3oool07@3oool001/0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`3:0?ooo`030000003oool0oooo01d0oooo000K0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0N0?ooo`006`3oool2000001L0oooo00<0
00000?ooo`3oool0b03oool00`000000oooo0?ooo`0N0?ooo`006`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool07`3oool001/0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo01l0oooo000K0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0P0?ooo`00
203oool2000000@0oooo0P0000030?ooo`D000000`3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0<@0oooo00<000000?ooo`3oool0803oool000L0oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
`P3oool00`000000oooo0?ooo`0Q0?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo00<0oooo0P00000J0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0
8@3oool000L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0R0?ooo`001`3o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo0280oooo00080?ooo`8000002P3o
ool2000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`2n0?ooo`030000003o
ool0oooo02<0oooo000K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0_P3oool0
0`000000oooo0?ooo`0S0?ooo`006`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0;`0oooo00<000000?ooo`3oool0903oool001/0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`2l0?ooo`030000003oool0oooo02@0oooo000K0?ooo`8000007P3oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo02D0oooo000K0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0^@3oool00`000000oooo0?ooo`0U0?ooo`006`3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool09P3oool001/0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo02H0oooo000K0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`0W0?ooo`00
6`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0
:03oool001/0oooo0P00000R0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0:03o
ool001/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0
oooo02T0oooo000K0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0/03oool00`00
0000oooo0?ooo`0Z0?ooo`006`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;00
oooo00<000000?ooo`3oool0:P3oool001/0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`2^0?ooo`030000003oool0oooo02/0oooo000K0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0[P3oool00`000000oooo0?ooo`0[0?ooo`006`3oool2000002D0oooo00<00000
0?ooo`3oool0[03oool00`000000oooo0?ooo`0/0?ooo`006`3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0;@3oool001/0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02d0oooo000K0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0^0?ooo`006`3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0;P3o
ool001/0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0
oooo02l0oooo000K0?ooo`800000:@3oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo
0300oooo000K0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0Y03oool00`000000
oooo0?ooo`0`0?ooo`006`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0:80oooo
00<000000?ooo`3oool0<@3oool001/0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`2P0?ooo`030000003oool0oooo0380oooo000K0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0X03oool00`000000oooo0?ooo`0b0?ooo`000P3oool2000000@0oooo0P0000030?oo
o`D000000P3oool2000000D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`2N0?oo
o`030000003oool0oooo03<0oooo00001@3oool000000?ooo`3oool0000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`2M0?ooo`030000003oool0oooo03<0oooo00001@3oool000000?ooo`3oool0
000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`800000;@3oool0
0`000000oooo0?ooo`2L0?ooo`030000003oool0oooo03@0oooo00001@3oool000000?ooo`3oool0
000000X0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`2J0?ooo`030000003oool0oooo03D0oooo00001@3oool000000?ooo`3oool0
000000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0e0?ooo`000P3oool20000
00X0oooo0P0000040?ooo`<00000103oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
09P0oooo00<000000?ooo`3oool0=P3oool001/0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`2F0?ooo`030000003oool0oooo03L0oooo000K0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0g0?ooo`006`3oool200000340oooo00<0
00000?ooo`3oool0U03oool00`000000oooo0?ooo`0h0?ooo`006`3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0>03oool001/0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03T0oooo000K0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0j0?ooo`00
6`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
>P3oool001/0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo03/0oooo000K0?ooo`800000=@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo03`0oooo000K0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0RP3oool00`00
0000oooo0?ooo`0m0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo08T0
oooo00<000000?ooo`3oool0?@3oool001/0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo03h0oooo000K0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`0o0?ooo`006`3oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0@03oool001/0oooo0P00000i0?oo
o`030000003oool0oooo08@0oooo00<000000?ooo`3oool0@03oool001/0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0440oooo000K0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`120?ooo`006`3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0@`3o
ool001/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0
oooo04<0oooo000K0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0O03oool00`00
0000oooo0?ooo`140?ooo`006`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo07X0
oooo00<000000?ooo`3oool0A@3oool001/0oooo0P00000o0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool0AP3oool001/0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo04L0oooo000K0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool0M@3oool00`000000oooo0?ooo`170?ooo`006`3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo07<0oooo00<000000?ooo`3oool0B03oool000P0oooo0P0000040?ooo`80
00000`3oool4000000@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1b0?ooo`03
0000003oool0oooo04T0oooo00070?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0700oooo00<000000?ooo`3o
ool0BP3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`80
0000A03oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo04/0oooo00070?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo06`0oooo00<000000?ooo`3oool0C03oool000L0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`1<0?ooo`00203oool2000000X0oooo0P0000050?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1=0?ooo`00
6`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0
CP3oool001/0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`1U0?ooo`030000003o
ool0oooo04l0oooo000K0?ooo`800000BP3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo0500oooo000K0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0H@3oool00`00
0000oooo0?ooo`1A0?ooo`006`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo05l0
oooo00<000000?ooo`3oool0DP3oool001/0oooo00<000000?ooo`3oool0C03oool2000005d0oooo
0P00001E0?ooo`006`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo05T0oooo00<0
00000?ooo`3oool0E@3oool001/0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo05H0oooo000K0?ooo`800000D@3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo05L0oooo000K0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`1H0?ooo`006`3oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool0F@3oool001/0oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`1>0?ooo`800000G03oool001/0oooo00<000000?ooo`3oool0E03oool2
000004d0oooo00<000000?ooo`3oool0G03oool001/0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo05d0oooo000K0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0AP3oool200000600oooo000K0?ooo`800000F@3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo0600oooo000K0?ooo`030000003oool0oooo05T0oooo0P00
00120?ooo`800000H`3oool001/0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo06<0oooo000K0?ooo`030000003oool0oooo05`0oooo0P00000l0?oo
o`800000IP3oool001/0oooo00<000000?ooo`3oool0GP3oool2000003P0oooo0P00001X0?ooo`00
6`3oool00`000000oooo0?ooo`1P0?ooo`800000=03oool2000006X0oooo000K0?ooo`800000H`3o
ool200000300oooo0P00001/0?ooo`006`3oool00`000000oooo0?ooo`1T0?ooo`800000;03oool2
000006h0oooo000K0?ooo`030000003oool0oooo06H0oooo0`00000W0?ooo`800000L03oool001/0
oooo00<000000?ooo`3oool0J@3oool2000002<0oooo0P00001b0?ooo`000P3oool2000000@0oooo
0P0000030?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool0J`3oool3000001d0oooo
0`00001d0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1^0?ooo`H000004@3oool6000007L0
oooo00001@3oool000000?ooo`3oool0000000T0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`800000M@3ooolA000007d0oooo00001@3oool000000?ooo`3oool0000000X0
oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
00D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`3o0?ooo`<0oooo00020?ooo`8000002P3oool2000000@0
oooo0`0000040?ooo`030000003oool0oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0
o`3oool30?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.107864, -0.0225047, \
0.00394728, 0.00159671}}]
}, Open  ]],

Cell[BoxData[{
    \(\(PlotColor[hue_] := 
        RGBColor @@ 
          If[hue \[Equal] 1, {1, 0, 0}, 
            Module[{x = Mod[4  hue, 1]}, 
              Switch[Mod[Floor[4  hue], 4], 0, {0, x, 1}, 1, {0, 1, 1 - x}, 
                2, {x, 1, 0}, 
                3, {1, 1 - x, 0}]]];\)\), "\[IndentingNewLine]", 
    \(a = 2.0; b = 2.0; L = 10.0; G = 1; dx = a/8; dy = b/8; dz = L/40; 
    J = 2.1849801331564294`;\), "\[IndentingNewLine]", 
    \(Clear[x, y, z, T]; 
    k = T\/\(G\ J\); \[CapitalPhi] = \(\(32  G\ k\ a\)\/\[Pi]\^3\) 
        Sum[\(1\/n\^3\) \(\((\(-1\))\)\^\(\(n - 1\)\/2\)\) \((1 - 
                Cosh[n\ \[Pi]\ y/\((2  a)\)]\/Cosh[n\ \[Pi]\ b/\((2  a)\)])\) 
            Cos[\(n\ \[Pi]\ x\)\/\(2  a\)], {n, 1, 10, 
            2}]; \[Tau]\_yz = \(-\[PartialD]\_x \[CapitalPhi]\); \[Tau]\_xz = \
\[PartialD]\_y \[CapitalPhi]; \[Gamma]\_yz = \[Tau]\_yz\/G; \[Gamma]\_xz = \
\[Tau]\_xz\/G;\), "\[IndentingNewLine]", 
    \(\(Rotate[{x_, y_, z_}, \[Theta]_] := {x\ Cos[\[Theta]] - 
            y\ Sin[\[Theta]], x\ Sin[\[Theta]] + y\ Cos[\[Theta]], 
          z};\)\), "\[IndentingNewLine]", 
    \(animation = {}; scale2 = 10.0; Tmax = scale2; 
    dt = 1.0/360;\), "\[IndentingNewLine]", 
    \(\(Prepare[T1_, z1_] := 
        Module[{}, \[Alpha] = k\ z1/scale2 /. T \[Rule] T1; 
          scale = \((\(x\^2 + y\^2\)\/\(\((x + \[Gamma]\_xz/2)\)\^2 + \((y + \
\[Gamma]\_yz/2)\)\^2\))\)\^\(1/2\) /. {x \[Rule] a/2, 
                y \[Rule] b/2}];\)\), "\[IndentingNewLine]", 
    \(\(Calculate[
          T1_, {x1_, y1_, 
            z1_}] := {Rotate[{scale \((x + \[Gamma]\_xz/2)\), 
                scale \((y + \[Gamma]\_yz/2)\), 
                z1 + scale \((x\ \[Gamma]\_xz + y\ \[Gamma]\_yz)\)/
                      2}, \[Alpha] - 
                ArcTan[\(1 + 0.09576080145730925`\ T\)\/\(1 - \
0.09332536922126035`\ T\)] - \[Pi]\/4], \((3 \((\[Tau]\_xz\%2 + \
\[Tau]\_yz\%2)\))\)\^\(1/2\)} /. {x \[Rule] x1, y \[Rule] y1, 
            T \[Rule] T1};\)\), "\[IndentingNewLine]", 
    \(\(Do[slices = {}; 
        Show[Graphics3D[{EdgeForm[], 
              Table[T = Tmax \((1 - Cos[2  \[Pi]\ t])\)/2; Prepare[T, z]; 
                slice1 = slice2; 
                slice2 = 
                  Map[Calculate[
                        T, {#\[LeftDoubleBracket]1\[RightDoubleBracket], #\
\[LeftDoubleBracket]2\[RightDoubleBracket], z}] &, 
                    Flatten[{Table[{x, \(-b\)/2}, {x, \(-a\)/2, a/2 - dx, 
                            dx}], Table[{a/2, y}, {y, \(-b\)/2, b/2 - dy, 
                            dy}], Table[{x, b/2}, {x, a/2, 
                            dx - a/2, \(-dx\)}], 
                        Table[{\(-a\)/2, y}, {y, b/2, dy - b/2, \(-dy\)}]}, 
                      1]]; slices = Append[slices, slice2]; 
                n = Length[slice2]; 
                If[z \[Equal] 0, 
                  Polygon[
                    Map[#\[LeftDoubleBracket]1\[RightDoubleBracket] &, 
                      slice2]], 
                  Table[quad = {slice1[\([i]\)], slice2[\([i]\)], 
                        slice2[\([Mod[i, n] + 1]\)], 
                        slice1[\([Mod[i, n] + 1]\)]}; {SurfaceColor[
                        PlotColor[\((Plus @@ 
                                  Map[#\[LeftDoubleBracket]2\
\[RightDoubleBracket] &, quad]/4)\)/4.632030522701348]], 
                      Polygon[
                        Map[#\[LeftDoubleBracket]1\[RightDoubleBracket] &, 
                          quad]]}, {i, 1, n}]], {z, 0, L, dz}]}, 
            ViewPoint \[Rule] {\(-1\), 1, 1}, ViewVertical \[Rule] {0, 1, 0}, 
            Axes \[Rule] True, AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<z\>"}, 
            PlotRange \[Rule] {{\(-a\), a}, {\(-b\), b}, {0, L}}]]; 
        animation = Append[animation, slices], {t, 0, 0.5, 
          dt}];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Zero[x_, n_] := 
        Module[{str = ToString[x]}, 
          StringJoin @@ 
            Append[Table["\<0\>", {n - StringLength[str]}], 
              str]];\)\), "\[IndentingNewLine]", 
    \(POVFormat[x_Real] := ToString[x, CForm]; 
    POVFormat[x_Integer] := ToString[x];\), "\[IndentingNewLine]", 
    \(\(POVFormat[{{x_, y_, z_}, \[Sigma]_}] := 
        StringJoin["\<<\>", POVFormat[x], "\<,\>", POVFormat[y], "\<,\>", 
          POVFormat[z], "\<,\>", 
          POVFormat[\[Sigma]], "\<>\>"];\)\), "\[IndentingNewLine]", 
    \(\(POVFormat[xlist_List] := 
        StringJoin["\<{\>", 
          StringJoin @@ Map[POVFormat[#] <> "\<,\>" &, Drop[xlist, \(-1\)]], 
          POVFormat[Last[xlist]], "\<}\>"];\)\), "\[IndentingNewLine]", 
    \(TakeLoop[list_, n_] := Take[Join[list, list], n]; 
    nslice = Length[
        animation\[LeftDoubleBracket]1\[RightDoubleBracket]];\), "\
\[IndentingNewLine]", 
    \(\(WriteVar[name_, x_] := 
        WriteString[wf, 
          StringJoin["\<#declare \>", name, "\<=array[\>", 
            ToString[Length[x]], "\<][\>", 
            ToString[
              Length[x\[LeftDoubleBracket]1\[RightDoubleBracket]]], "\<] \>", 
            POVFormat[x], "\<;\n\>"]];\)\), "\[IndentingNewLine]", 
    \(\(Do[T = Tmax \((1 - Cos[2  \[Pi]\ t])\)/2; frame = Round[t/dt + 1]; 
        slices = animation\[LeftDoubleBracket]frame\[RightDoubleBracket]; 
        wf = OpenWrite[
            StringJoin["\<C:/Files/PovRay/Physics/Torsion/\>", 
              Zero[frame, 3], "\<.inc\>"]]; \[IndentingNewLine]Do[
          WriteVar[StringJoin["\<wall\>", ToString[iwall]], 
            Table[TakeLoop[
                slices\[LeftDoubleBracket]islice\[RightDoubleBracket], 
                8 {iwall - 1, iwall} + 1], {islice, 1, nslice}]], {iwall, 1, 
            4}]; Prepare[T, 0]; 
        WriteVar["\<cap1\>", 
          Table[Calculate[T, {x, y, 0}], {y, \(-b\)/2, b/2, 
              dy}, {x, \(-a\)/2, a/2, dx}]]; \[IndentingNewLine]Prepare[T, 
          L]; WriteVar["\<cap2\>", 
          Table[Calculate[T, {x, y, L}], {y, \(-b\)/2, b/2, 
              dy}, {x, \(-a\)/2, a/2, dx}]]; \[IndentingNewLine]Close[
          wf], {t, 0, 0.5, dt}];\)\)}], "Input"],

Cell[BoxData[{
    \(\(CopyScaleExport["\<C:/Files/Animated Gifs/Torsion\>", 
        140, "\<*.bmp\>"];\)\), "\[IndentingNewLine]", 
    \(\(CopyScaleExport["\<C:/Files/Animated Gifs/Torsion\>", 
        70, "\<*.bmp\>"];\)\)}], "Input"],

Cell[BoxData[
    \(\(Export["\<C:/Files/Animated Gifs/Torsion/Torsion.gif\>", 
        Map[Import[#\[LeftDoubleBracket]1\[RightDoubleBracket]] &, 
          Partition[
            FileNames["\<*.bmp\>", "\<C:/Files/Animated Gifs/Torsion\>"], 1, 
            1]], ConversionOptions \[Rule] {"\<AnimationDisplayTime\>" \
\[Rule] 0, "\<Loop\>" \[Rule] True, "\<GlobalColorReduction\>" \[Rule] 
              True}];\)\)], "Input"],

Cell[" ", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 0.5}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 3}]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 727}},
WindowSize->{978, 686},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 86, 2, 33, "Text"],
Cell[1843, 55, 208, 6, 52, "Text"],
Cell[2054, 63, 284, 9, 10, "Text"],
Cell[2341, 74, 71, 0, 33, "Text"],
Cell[2415, 76, 286, 9, 5, "Text"],
Cell[2704, 87, 77, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2806, 91, 36, 0, 43, "Subsubsection"],
Cell[2845, 93, 1657, 28, 187, "Text"],
Cell[4505, 123, 897, 16, 83, "Text"],
Cell[5405, 141, 57, 1, 29, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5499, 147, 44, 0, 43, "Subsubsection"],
Cell[5546, 149, 174, 3, 29, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5757, 157, 60, 0, 43, "Subsubsection"],
Cell[5820, 159, 508, 9, 125, "Text"],
Cell[6331, 170, 37, 1, 29, "Input"],
Cell[6371, 173, 3052, 49, 504, "Text"],

Cell[CellGroupData[{
Cell[9448, 226, 668, 10, 108, "Input"],
Cell[10119, 238, 97981, 1639, 296, 27294, 762, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[108115, 1880, 474, 8, 69, "Text"],

Cell[CellGroupData[{
Cell[108614, 1892, 130, 3, 48, "Input"],
Cell[108747, 1897, 35, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[108819, 1903, 68, 1, 29, "Input"],
Cell[108890, 1906, 21642, 495, 186, 3932, 272, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[130547, 2404, 3825, 70, 493, "Input"],
Cell[134375, 2476, 2231, 43, 257, "Input"],
Cell[136609, 2521, 238, 4, 48, "Input"],
Cell[136850, 2527, 428, 7, 48, "Input"],
Cell[137281, 2536, 286, 9, 5, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

